@@ -769,6 +769,12 @@ static pj_bool_t on_connect_complete(pj_turn_sock *turn_sock,
         return PJ_FALSE;
     }
 
+    /* Check if session is being destroyed. */
+    if (pj_turn_session_get_state(turn_sock->sess) >= PJ_TURN_STATE_DESTROYING) {
+        pj_grp_lock_release(turn_sock->grp_lock);
+        return PJ_FALSE;
+    }
+
     if (status != PJ_SUCCESS) {
         if (turn_sock->conn_type == PJ_TURN_TP_UDP)
             sess_fail(turn_sock, "UDP connect() error", status);
@@ -1278,9 +1284,7 @@ static void turn_on_state(pj_turn_session *sess,
 
     /* Make sure user hasn't destroyed us in the callback */
     if (turn_sock->sess && new_state == PJ_TURN_STATE_RESOLVED) {
-        pj_turn_session_info info;
-        pj_turn_session_get_info(turn_sock->sess, &info);
-        new_state = info.state;
+        new_state = pj_turn_session_get_state(turn_sock->sess);
     }
 
     if (turn_sock->sess && new_state == PJ_TURN_STATE_RESOLVED) {
