@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,10 @@ class base64_exception : public std::exception
 
 std::string encode(std::string_view);
 
-inline std::string encode(const std::vector<uint8_t>& data) {
-    return encode(std::string_view((const char*)data.data(), data.size()));
+inline std::string
+encode(const std::vector<uint8_t>& data)
+{
+    return encode(std::string_view((const char*) data.data(), data.size()));
 }
 
 std::vector<uint8_t> decode(std::string_view);
