@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,11 +48,13 @@ namespace jami {
 
 class Call;
 class Account;
+class JamiAccount;
 
 #ifdef ENABLE_VIDEO
 namespace video {
 class VideoMixer;
-}
+struct SourceInfo;
+} // namespace video
 #endif
 
 // info for a stream
@@ -135,19 +137,14 @@ struct ParticipantInfo
 
     friend bool operator==(const ParticipantInfo& p1, const ParticipantInfo& p2)
     {
-        return p1.uri == p2.uri and p1.device == p2.device and p1.sinkId == p2.sinkId
-               and p1.active == p2.active and p1.x == p2.x and p1.y == p2.y and p1.w == p2.w
-               and p1.h == p2.h and p1.videoMuted == p2.videoMuted
-               and p1.audioLocalMuted == p2.audioLocalMuted
-               and p1.audioModeratorMuted == p2.audioModeratorMuted
+        return p1.uri == p2.uri and p1.device == p2.device and p1.sinkId == p2.sinkId and p1.active == p2.active
+               and p1.x == p2.x and p1.y == p2.y and p1.w == p2.w and p1.h == p2.h and p1.videoMuted == p2.videoMuted
+               and p1.audioLocalMuted == p2.audioLocalMuted and p1.audioModeratorMuted == p2.audioModeratorMuted
                and p1.isModerator == p2.isModerator and p1.handRaised == p2.handRaised
                and p1.voiceActivity == p2.voiceActivity and p1.recording == p2.recording;
     }
 
-    friend bool operator!=(const ParticipantInfo& p1, const ParticipantInfo& p2)
-    {
-        return !(p1 == p2);
-    }
+    friend bool operator!=(const ParticipantInfo& p1, const ParticipantInfo& p2) { return !(p1 == p2); }
 };
 
 struct ConfInfo : public std::vector<ParticipantInfo>
@@ -165,9 +162,7 @@ struct ConfInfo : public std::vector<ParticipantInfo>
             return false;
 
         for (auto& p1 : c1) {
-            auto it = std::find_if(c2.begin(), c2.end(), [&p1](const ParticipantInfo& p2) {
-                return p1 == p2;
-            });
+            auto it = std::find_if(c2.begin(), c2.end(), [&p1](const ParticipantInfo& p2) { return p1 == p2; });
             if (it != c2.end())
                 continue;
             else
@@ -193,8 +188,7 @@ public:
     /**
      * Constructor for this class, increment static counter
      */
-    explicit Conference(const std::shared_ptr<Account>&,
-                        const std::string& confId = "");
+    explicit Conference(const std::shared_ptr<Account>&, const std::string& confId = "");
 
     /**
      * Destructor for this class, decrement static counter
@@ -285,7 +279,7 @@ public:
     /**
      * Attach host
      */
-    void attachHost(const std::vector<libjami::MediaMap>& mediaList = {});
+    void attachHost(const std::vector<libjami::MediaMap>& mediaList);
 
     /**
      * Detach local audio/video from the conference
@@ -365,6 +359,12 @@ public:
      */
     std::vector<libjami::MediaMap> currentMediaList() const;
 
+    /**
+     * Return the last media list before the host was detached
+     * @return Last media list
+     */
+    std::vector<libjami::MediaMap> getLastMediaList() const { return lastMediaList_; }
+
     // Update layout if recording changes
     void stopRecording() override;
     bool startRecording(const std::string& path) override;
@@ -376,15 +376,11 @@ public:
     {
         return duration_start_ == clock::time_point::min()
                    ? std::chrono::milliseconds::zero()
-                   : std::chrono::duration_cast<std::chrono::milliseconds>(clock::now()
-                                                                           - duration_start_);
+                   : std::chrono::duration_cast<std::chrono::milliseconds>(clock::now() - duration_start_);
     }
 
 private:
-    std::weak_ptr<Conference> weak()
-    {
-        return std::static_pointer_cast<Conference>(shared_from_this());
-    }
+    std::weak_ptr<Conference> weak() { return std::static_pointer_cast<Conference>(shared_from_this()); }
 
     static std::shared_ptr<Call> getCall(const std::string& callId);
     bool isModerator(std::string_view uri) const;
@@ -442,14 +438,16 @@ private:
     // Because host doesn't have a call, we need to store the audio inputs
     std::map<std::string, std::shared_ptr<jami::AudioInput>> hostAudioInputs_;
 
+    // Last media list before detaching from a conference
+    std::vector<libjami::MediaMap> lastMediaList_ = {};
+
     bool localModAdded_ {false};
 
     std::map<std::string, ConfInfo> remoteHosts_;
 #ifdef ENABLE_VIDEO
     void resizeRemoteParticipants(ConfInfo& confInfo, std::string_view peerURI);
 #endif
-    std::string_view findHostforRemoteParticipant(std::string_view uri,
-                                                  std::string_view deviceId = "");
+    std::string_view findHostforRemoteParticipant(std::string_view uri, std::string_view deviceId = "");
 
     std::shared_ptr<Call> getCallWith(const std::string& accountUri, const std::string& deviceId);
 
@@ -504,6 +502,44 @@ private:
      */
     void initSourcesForHost();
 
+#ifdef ENABLE_VIDEO
+    /**
+     * Setup video mixer and its callbacks.
+     * Called during construction.
+     */
+    void setupVideoMixer();
+
+    /**
+     * Callback for when video sources are updated.
+     * @param infos The updated source information
+     */
+    void onVideoSourcesUpdated(const std::vector<video::SourceInfo>& infos);
+
+    /**
+     * Create participant info for a remote call source.
+     * @param info Source information from video mixer
+     * @return Populated ParticipantInfo
+     */
+    ParticipantInfo createParticipantInfoFromRemoteSource(const video::SourceInfo& info);
+
+    /**
+     * Create participant info for a local/host source.
+     * @param info Source information from video mixer
+     * @param acc The JamiAccount for the host
+     * @param hostAdded Output flag indicating if host was added
+     * @return Populated ParticipantInfo
+     */
+    ParticipantInfo createParticipantInfoFromLocalSource(const video::SourceInfo& info,
+                                                         const std::shared_ptr<JamiAccount>& acc,
+                                                         bool& hostAdded);
+#endif
+
+    /**
+     * Register all protocol message handlers.
+     * Called during construction.
+     */
+    void registerProtocolHandlers();
+
     /**
      * Take over media control from the call.
      * When a call joins a conference, the media control (mainly mute/un-mute
@@ -531,6 +567,21 @@ private:
      * Unbind call's audio from the conference
      */
     void unbindSubCallAudio(const std::string& callId);
+
+    /**
+     * Clear all participant data from the conference
+     */
+    void clearParticipantData(const std::string& callId);
+
+#ifdef ENABLE_VIDEO
+    /**
+     * Make sure video is negotiated with all subcalls
+     * When the conference needs video (host has video or any participant has video),
+     * this method triggers renegotiation with subcalls that don't have video yet.
+     * @param excludeCallId Optional call ID to exclude from renegotiation (e.g., the call that just added video)
+     */
+    void negotiateVideoWithSubcalls(const std::string& excludeCallId = "");
+#endif
 };
 
 } // namespace jami
