@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,6 +60,8 @@
 #include "windirent.h"
 #endif
 
+#include <filesystem>
+
 namespace jami {
 namespace tls {
 
@@ -130,31 +132,30 @@ const CallbackMatrix1D<TlsValidator::CertificateDetails, TlsValidator, TlsValida
         /* IS_CA                        */ &TlsValidator::isCA,
     }};
 
-const Matrix1D<TlsValidator::CertificateCheck, TlsValidator::CheckValuesType>
-    TlsValidator::enforcedCheckType = {{
-        /*      CertificateCheck                    Callback        */
-        /*HAS_PRIVATE_KEY                  */ CheckValuesType::BOOLEAN,
-        /*EXPIRED                          */ CheckValuesType::BOOLEAN,
-        /*STRONG_SIGNING                   */ CheckValuesType::BOOLEAN,
-        /*NOT_SELF_SIGNED                  */ CheckValuesType::BOOLEAN,
-        /*KEY_MATCH                        */ CheckValuesType::BOOLEAN,
-        /*PRIVATE_KEY_STORAGE_PERMISSION   */ CheckValuesType::BOOLEAN,
-        /*PUBLIC_KEY_STORAGE_PERMISSION    */ CheckValuesType::BOOLEAN,
-        /*PRIVATEKEY_DIRECTORY_PERMISSIONS */ CheckValuesType::BOOLEAN,
-        /*PUBLICKEY_DIRECTORY_PERMISSIONS  */ CheckValuesType::BOOLEAN,
-        /*PRIVATE_KEY_STORAGE_LOCATION     */ CheckValuesType::BOOLEAN,
-        /*PUBLIC_KEY_STORAGE_LOCATION      */ CheckValuesType::BOOLEAN,
-        /*PRIVATE_KEY_SELINUX_ATTRIBUTES   */ CheckValuesType::BOOLEAN,
-        /*PUBLIC_KEY_SELINUX_ATTRIBUTES    */ CheckValuesType::BOOLEAN,
-        /*EXIST                            */ CheckValuesType::BOOLEAN,
-        /*VALID                            */ CheckValuesType::BOOLEAN,
-        /*VALID_AUTHORITY                  */ CheckValuesType::BOOLEAN,
-        /*KNOWN_AUTHORITY                  */ CheckValuesType::BOOLEAN,
-        /*NOT_REVOKED                      */ CheckValuesType::BOOLEAN,
-        /*AUTHORITY_MISMATCH               */ CheckValuesType::BOOLEAN,
-        /*UNEXPECTED_OWNER                 */ CheckValuesType::BOOLEAN,
-        /*NOT_ACTIVATED                    */ CheckValuesType::BOOLEAN,
-    }};
+const Matrix1D<TlsValidator::CertificateCheck, TlsValidator::CheckValuesType> TlsValidator::enforcedCheckType = {{
+    /*      CertificateCheck                    Callback        */
+    /*HAS_PRIVATE_KEY                  */ CheckValuesType::BOOLEAN,
+    /*EXPIRED                          */ CheckValuesType::BOOLEAN,
+    /*STRONG_SIGNING                   */ CheckValuesType::BOOLEAN,
+    /*NOT_SELF_SIGNED                  */ CheckValuesType::BOOLEAN,
+    /*KEY_MATCH                        */ CheckValuesType::BOOLEAN,
+    /*PRIVATE_KEY_STORAGE_PERMISSION   */ CheckValuesType::BOOLEAN,
+    /*PUBLIC_KEY_STORAGE_PERMISSION    */ CheckValuesType::BOOLEAN,
+    /*PRIVATEKEY_DIRECTORY_PERMISSIONS */ CheckValuesType::BOOLEAN,
+    /*PUBLICKEY_DIRECTORY_PERMISSIONS  */ CheckValuesType::BOOLEAN,
+    /*PRIVATE_KEY_STORAGE_LOCATION     */ CheckValuesType::BOOLEAN,
+    /*PUBLIC_KEY_STORAGE_LOCATION      */ CheckValuesType::BOOLEAN,
+    /*PRIVATE_KEY_SELINUX_ATTRIBUTES   */ CheckValuesType::BOOLEAN,
+    /*PUBLIC_KEY_SELINUX_ATTRIBUTES    */ CheckValuesType::BOOLEAN,
+    /*EXIST                            */ CheckValuesType::BOOLEAN,
+    /*VALID                            */ CheckValuesType::BOOLEAN,
+    /*VALID_AUTHORITY                  */ CheckValuesType::BOOLEAN,
+    /*KNOWN_AUTHORITY                  */ CheckValuesType::BOOLEAN,
+    /*NOT_REVOKED                      */ CheckValuesType::BOOLEAN,
+    /*AUTHORITY_MISMATCH               */ CheckValuesType::BOOLEAN,
+    /*UNEXPECTED_OWNER                 */ CheckValuesType::BOOLEAN,
+    /*NOT_ACTIVATED                    */ CheckValuesType::BOOLEAN,
+}};
 
 const EnumClassNames<TlsValidator::CertificateCheck> TlsValidator::CertificateCheckNames = {{
     /*      CertificateCheck                                   Name */
@@ -218,8 +219,8 @@ const EnumClassNames<const TlsValidator::CheckValuesType> TlsValidator::CheckVal
     /* NUMBER   */ libjami::Certificate::ChecksValuesTypesNames::NUMBER,
 }};
 
-const Matrix2D<TlsValidator::CheckValuesType, TlsValidator::CheckValues, bool>
-    TlsValidator::acceptedCheckValuesResult = {{
+const Matrix2D<TlsValidator::CheckValuesType, TlsValidator::CheckValues, bool> TlsValidator::acceptedCheckValuesResult = {
+    {
         /*   Type          PASSED    FAILED   UNSUPPORTED   ISO_DATE    CUSTOM    NUMBER */
         /* BOOLEAN  */ {{true, true, true, false, false, false}},
         /* ISO_DATE */ {{false, false, true, true, false, false}},
@@ -227,7 +228,8 @@ const Matrix2D<TlsValidator::CheckValuesType, TlsValidator::CheckValues, bool>
         /* NUMBER   */ {{false, false, true, false, false, true}},
     }};
 
-TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore, const std::vector<std::vector<uint8_t>>& crtChain)
+TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore,
+                           const std::vector<std::vector<uint8_t>>& crtChain)
     : TlsValidator(certStore, std::make_shared<dht::crypto::Certificate>(crtChain.begin(), crtChain.end()))
 {}
 
@@ -287,7 +289,8 @@ TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore, const
     }
 }
 
-TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore, const std::shared_ptr<dht::crypto::Certificate>& crt)
+TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore,
+                           const std::shared_ptr<dht::crypto::Certificate>& crt)
     : certStore_(certStore)
     , certificateFound_(true)
 {
@@ -309,7 +312,7 @@ TlsValidator::~TlsValidator() {}
  * @todo The date should be validated, this is currently not an issue
  */
 std::string
-TlsValidator::getStringValue([[maybe_unused]]const TlsValidator::CertificateCheck check,
+TlsValidator::getStringValue([[maybe_unused]] const TlsValidator::CertificateCheck check,
                              const TlsValidator::CheckResult result)
 {
     assert(acceptedCheckValuesResult[enforcedCheckType[check]][result.first]);
@@ -364,11 +367,10 @@ TlsValidator::getSerializedChecks()
     if (not certificateFound_) {
         // Instead of checking `certificateFound` everywhere, handle it once
         ret[std::string(CertificateCheckNames[CertificateCheck::EXIST])] = getStringValue(CertificateCheck::EXIST,
-                                                                             exist());
+                                                                                          exist());
     } else {
         for (const CertificateCheck check : Matrix0D<CertificateCheck>())
-            ret[std::string(CertificateCheckNames[check])] = getStringValue(check,
-                                                               (this->*(checkCallback[check]))());
+            ret[std::string(CertificateCheckNames[check])] = getStringValue(check, (this->*(checkCallback[check]))());
     }
 
     return ret;
@@ -413,12 +415,9 @@ TlsValidator::getSerializedDetails()
 static TlsValidator::CheckResult
 checkError(int err, char* copy_buffer, size_t size)
 {
-    return TlsValidator::TlsValidator::CheckResult(err == GNUTLS_E_SUCCESS
-                                                       ? TlsValidator::CheckValues::CUSTOM
-                                                       : TlsValidator::CheckValues::UNSUPPORTED,
-                                                   err == GNUTLS_E_SUCCESS
-                                                       ? std::string(copy_buffer, size)
-                                                       : "");
+    return TlsValidator::TlsValidator::CheckResult(err == GNUTLS_E_SUCCESS ? TlsValidator::CheckValues::CUSTOM
+                                                                           : TlsValidator::CheckValues::UNSUPPORTED,
+                                                   err == GNUTLS_E_SUCCESS ? std::string(copy_buffer, size) : "");
 }
 
 /**
@@ -443,8 +442,7 @@ checkBinaryError(int err, char* copy_buffer, size_t resultSize)
 {
     if (err == GNUTLS_E_SUCCESS)
         return TlsValidator::CheckResult(TlsValidator::CheckValues::CUSTOM,
-                                         dht::toHex(reinterpret_cast<uint8_t*>(copy_buffer),
-                                                     resultSize));
+                                         dht::toHex(reinterpret_cast<uint8_t*>(copy_buffer), resultSize));
     else
         return TlsValidator::CheckResult(TlsValidator::CheckValues::UNSUPPORTED, "");
 }
@@ -470,19 +468,9 @@ TlsValidator::compareToCa()
 
     if (not caListPath_.empty()) {
         if (std::filesystem::is_directory(caListPath_))
-            gnutls_x509_trust_list_add_trust_dir(trust,
-                                                 caListPath_.c_str(),
-                                                 nullptr,
-                                                 GNUTLS_X509_FMT_PEM,
-                                                 0,
-                                                 0);
+            gnutls_x509_trust_list_add_trust_dir(trust, caListPath_.c_str(), nullptr, GNUTLS_X509_FMT_PEM, 0, 0);
         else
-            gnutls_x509_trust_list_add_trust_file(trust,
-                                                  caListPath_.c_str(),
-                                                  nullptr,
-                                                  GNUTLS_X509_FMT_PEM,
-                                                  0,
-                                                  0);
+            gnutls_x509_trust_list_add_trust_file(trust, caListPath_.c_str(), nullptr, GNUTLS_X509_FMT_PEM, 0, 0);
     }
 
     // build the certificate chain
@@ -784,8 +772,7 @@ TlsValidator::notExpired()
         TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
 
     // time_t expirationTime = gnutls_x509_crt_get_expiration_time(cert);
-    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_EXPIRED ? CheckValues::FAILED
-                                                                         : CheckValues::PASSED,
+    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_EXPIRED ? CheckValues::FAILED : CheckValues::PASSED,
                                      "");
 }
 
@@ -801,9 +788,8 @@ TlsValidator::activated()
         TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
 
     // time_t activationTime = gnutls_x509_crt_get_activation_time(cert);
-    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_NOT_ACTIVATED
-                                         ? CheckValues::FAILED
-                                         : CheckValues::PASSED,
+    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_NOT_ACTIVATED ? CheckValues::FAILED
+                                                                               : CheckValues::PASSED,
                                      "");
 }
 
@@ -820,9 +806,8 @@ TlsValidator::strongSigning()
     // Doesn't seem to have the same value as
     // certtool  --infile /home/etudiant/Téléchargements/mynsauser.pem --key-inf
     // TODO figure out why
-    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_INSECURE_ALGORITHM
-                                         ? CheckValues::FAILED
-                                         : CheckValues::PASSED,
+    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_INSECURE_ALGORITHM ? CheckValues::FAILED
+                                                                                    : CheckValues::PASSED,
                                      "");
 }
 
@@ -846,8 +831,7 @@ TlsValidator::keyMatch()
 
     if (not privateKeyFound_)
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
-    return TlsValidator::CheckResult(privateKeyMatch_ ? CheckValues::PASSED : CheckValues::FAILED,
-                                     "");
+    return TlsValidator::CheckResult(privateKeyMatch_ ? CheckValues::PASSED : CheckValues::FAILED, "");
 }
 
 TlsValidator::CheckResult
@@ -858,7 +842,7 @@ TlsValidator::privateKeyStoragePermissions()
     if (err)
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
 
-// clang-format off
+    // clang-format off
     return TlsValidator::CheckResult(
         (statbuf.st_mode & S_IFREG) && /* Regular file only */
         /*                          READ                      WRITE                            EXECUTE          */
@@ -866,7 +850,7 @@ TlsValidator::privateKeyStoragePermissions()
         /* Group */ && (!(statbuf.st_mode & S_IRGRP) && !(statbuf.st_mode & S_IWGRP) && !(statbuf.st_mode & S_IXGRP))
         /* Other */ && (!(statbuf.st_mode & S_IROTH) && !(statbuf.st_mode & S_IWOTH) && !(statbuf.st_mode & S_IXOTH))
         ? CheckValues::PASSED:CheckValues::FAILED, "");
-// clang-format on
+    // clang-format on
 }
 
 TlsValidator::CheckResult
@@ -877,7 +861,7 @@ TlsValidator::publicKeyStoragePermissions()
     if (err)
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
 
-// clang-format off
+    // clang-format off
     return TlsValidator::CheckResult(
         (statbuf.st_mode & S_IFREG) && /* Regular file only */
         /*                          READ                      WRITE                            EXECUTE          */
@@ -885,74 +869,73 @@ TlsValidator::publicKeyStoragePermissions()
         /* Group */ && ( /* read is not relevant */   !(statbuf.st_mode & S_IWGRP) && !(statbuf.st_mode & S_IXGRP))
         /* Other */ && ( /* read is not relevant */   !(statbuf.st_mode & S_IWOTH) && !(statbuf.st_mode & S_IXOTH))
         ? CheckValues::PASSED:CheckValues::FAILED, "");
-// clang-format on
+    // clang-format on
 }
 
 TlsValidator::CheckResult
 TlsValidator::privateKeyDirectoryPermissions()
 {
+    namespace fs = std::filesystem;
+
     if (privateKeyPath_.empty())
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
 
-#ifndef _MSC_VER
-    auto path = std::unique_ptr<char, decltype(free)&>(strdup(privateKeyPath_.c_str()), free);
-    const char* dir = dirname(path.get());
-#else
-    char* dir;
-    _splitpath(certificatePath_.c_str(), nullptr, dir, nullptr, nullptr);
-#endif
+    fs::path dir = fs::path(privateKeyPath_).parent_path();
+    if (dir.empty())
+        dir = fs::path("."); // mimic dirname() behavior when no separator
 
-    struct stat statbuf;
-    int err = stat(dir, &statbuf);
-    if (err)
+    std::error_code ec;
+    auto st = fs::status(dir, ec);
+    if (ec)
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
 
-    return TlsValidator::CheckResult(
-        /*                          READ                      WRITE EXECUTE             */
-        /* Owner */ (
-            (statbuf.st_mode & S_IRUSR) /* write is not relevant */ && (statbuf.st_mode & S_IXUSR))
-                /* Group */
-                && (!(statbuf.st_mode & S_IRGRP) && !(statbuf.st_mode & S_IWGRP)
-                    && !(statbuf.st_mode & S_IXGRP))
-                /* Other */
-                && (!(statbuf.st_mode & S_IROTH) && !(statbuf.st_mode & S_IWOTH)
-                    && !(statbuf.st_mode & S_IXOTH))
-                && S_ISDIR(statbuf.st_mode)
-            ? CheckValues::PASSED
-            : CheckValues::FAILED,
-        "");
+    if (!fs::is_directory(st))
+        return TlsValidator::CheckResult(CheckValues::FAILED, "");
+
+    auto perm = st.permissions();
+
+    bool ownerRead = (perm & fs::perms::owner_read) != fs::perms::none;
+    bool ownerExec = (perm & fs::perms::owner_exec) != fs::perms::none;
+    bool groupAny = (perm & (fs::perms::group_read | fs::perms::group_write | fs::perms::group_exec))
+                    != fs::perms::none;
+    bool othersAny = (perm & (fs::perms::others_read | fs::perms::others_write | fs::perms::others_exec))
+                     != fs::perms::none;
+
+    bool ok = ownerRead && ownerExec && !groupAny && !othersAny;
+    return TlsValidator::CheckResult(ok ? CheckValues::PASSED : CheckValues::FAILED, "");
 }
 
 TlsValidator::CheckResult
 TlsValidator::publicKeyDirectoryPermissions()
 {
-#ifndef _MSC_VER
-    auto path = std::unique_ptr<char, decltype(free)&>(strdup(certificatePath_.c_str()), free);
-    const char* dir = dirname(path.get());
-#else
-    char* dir;
-    _splitpath(certificatePath_.c_str(), nullptr, dir, nullptr, nullptr);
-#endif
+    namespace fs = std::filesystem;
 
-    struct stat statbuf;
-    int err = stat(dir, &statbuf);
-    if (err)
+    if (certificatePath_.empty())
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
 
-    return TlsValidator::CheckResult(
-        /*                          READ                      WRITE EXECUTE             */
-        /* Owner */ (
-            (statbuf.st_mode & S_IRUSR) /* write is not relevant */ && (statbuf.st_mode & S_IXUSR))
-                /* Group */
-                && (!(statbuf.st_mode & S_IRGRP) && !(statbuf.st_mode & S_IWGRP)
-                    && !(statbuf.st_mode & S_IXGRP))
-                /* Other */
-                && (!(statbuf.st_mode & S_IROTH) && !(statbuf.st_mode & S_IWOTH)
-                    && !(statbuf.st_mode & S_IXOTH))
-                && S_ISDIR(statbuf.st_mode)
-            ? CheckValues::PASSED
-            : CheckValues::FAILED,
-        "");
+    fs::path dir = fs::path(certificatePath_).parent_path();
+    if (dir.empty())
+        return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
+
+    std::error_code ec;
+    auto st = fs::status(dir, ec);
+    if (ec)
+        return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
+
+    if (!fs::is_directory(st))
+        return TlsValidator::CheckResult(CheckValues::FAILED, "");
+
+    auto perm = st.permissions();
+
+    bool ownerRead = (perm & fs::perms::owner_read) != fs::perms::none;
+    bool ownerExec = (perm & fs::perms::owner_exec) != fs::perms::none;
+    bool groupAny = (perm & (fs::perms::group_read | fs::perms::group_write | fs::perms::group_exec))
+                    != fs::perms::none;
+    bool othersAny = (perm & (fs::perms::others_read | fs::perms::others_write | fs::perms::others_exec))
+                     != fs::perms::none;
+
+    bool ok = ownerRead && ownerExec && !groupAny && !othersAny;
+    return TlsValidator::CheckResult(ok ? CheckValues::PASSED : CheckValues::FAILED, "");
 }
 
 /**
@@ -1003,8 +986,7 @@ TlsValidator::publicKeySelinuxAttributes()
 TlsValidator::CheckResult
 TlsValidator::requirePrivateKeyPassword()
 {
-    return TlsValidator::CheckResult(privateKeyPassword_ ? CheckValues::PASSED : CheckValues::FAILED,
-                                     "");
+    return TlsValidator::CheckResult(privateKeyPassword_ ? CheckValues::PASSED : CheckValues::FAILED, "");
 }
 /**
  * The CA and certificate provide conflicting ownership information
@@ -1012,9 +994,8 @@ TlsValidator::requirePrivateKeyPassword()
 TlsValidator::CheckResult
 TlsValidator::expectedOwner()
 {
-    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_UNEXPECTED_OWNER
-                                         ? CheckValues::FAILED
-                                         : CheckValues::PASSED,
+    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_UNEXPECTED_OWNER ? CheckValues::FAILED
+                                                                                  : CheckValues::PASSED,
                                      "");
 }
 
@@ -1024,9 +1005,8 @@ TlsValidator::expectedOwner()
 TlsValidator::CheckResult
 TlsValidator::exist()
 {
-    return TlsValidator::CheckResult((certificateFound_ or certificateFileFound_)
-                                         ? CheckValues::PASSED
-                                         : CheckValues::FAILED,
+    return TlsValidator::CheckResult((certificateFound_ or certificateFileFound_) ? CheckValues::PASSED
+                                                                                  : CheckValues::FAILED,
                                      "");
 }
 
@@ -1038,8 +1018,7 @@ TlsValidator::exist()
 TlsValidator::CheckResult
 TlsValidator::valid()
 {
-    return TlsValidator::CheckResult(certificateFound_ ? CheckValues::PASSED : CheckValues::FAILED,
-                                     "");
+    return TlsValidator::CheckResult(certificateFound_ ? CheckValues::PASSED : CheckValues::FAILED, "");
 }
 
 /**
@@ -1049,9 +1028,8 @@ TlsValidator::CheckResult
 TlsValidator::validAuthority()
 {
     // TODO Merge with either above or below
-    return TlsValidator::CheckResult((compareToCa() & GNUTLS_CERT_SIGNER_NOT_FOUND)
-                                         ? CheckValues::FAILED
-                                         : CheckValues::PASSED,
+    return TlsValidator::CheckResult((compareToCa() & GNUTLS_CERT_SIGNER_NOT_FOUND) ? CheckValues::FAILED
+                                                                                    : CheckValues::PASSED,
                                      "");
 }
 
@@ -1061,9 +1039,8 @@ TlsValidator::validAuthority()
 TlsValidator::CheckResult
 TlsValidator::authorityMatch()
 {
-    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_SIGNER_NOT_CA
-                                         ? CheckValues::FAILED
-                                         : CheckValues::PASSED,
+    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_SIGNER_NOT_CA ? CheckValues::FAILED
+                                                                               : CheckValues::PASSED,
                                      "");
 }
 
@@ -1080,9 +1057,8 @@ TlsValidator::knownAuthority()
 {
     // TODO need a new boolean account setting "require trusted authority" or something defaulting
     // to true using GNUTLS_CERT_SIGNER_NOT_FOUND is a temporary placeholder as it is close enough
-    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_SIGNER_NOT_FOUND
-                                         ? CheckValues::FAILED
-                                         : CheckValues::PASSED,
+    return TlsValidator::CheckResult(compareToCa() & GNUTLS_CERT_SIGNER_NOT_FOUND ? CheckValues::FAILED
+                                                                                  : CheckValues::PASSED,
                                      "");
 }
 
@@ -1093,8 +1069,7 @@ TlsValidator::CheckResult
 TlsValidator::notRevoked()
 {
     return TlsValidator::CheckResult((compareToCa() & GNUTLS_CERT_REVOKED)
-                                             || (compareToCa()
-                                                 & GNUTLS_CERT_REVOCATION_DATA_ISSUED_IN_FUTURE)
+                                             || (compareToCa() & GNUTLS_CERT_REVOCATION_DATA_ISSUED_IN_FUTURE)
                                          ? CheckValues::FAILED
                                          : CheckValues::PASSED,
                                      "");
@@ -1178,8 +1153,7 @@ TlsValidator::CheckResult
 TlsValidator::getSubjectKeyAlgorithm()
 {
     unsigned key_length = 0;
-    gnutls_pk_algorithm_t algo = (gnutls_pk_algorithm_t)
-        gnutls_x509_crt_get_pk_algorithm(x509crt_->cert, &key_length);
+    gnutls_pk_algorithm_t algo = (gnutls_pk_algorithm_t) gnutls_x509_crt_get_pk_algorithm(x509crt_->cert, &key_length);
 
     if (algo < 0)
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
@@ -1218,12 +1192,7 @@ TlsValidator::getCN()
 {
     // TODO split, cache
     size_t resultSize = sizeof(copy_buffer);
-    int err = gnutls_x509_crt_get_dn_by_oid(x509crt_->cert,
-                                            GNUTLS_OID_X520_COMMON_NAME,
-                                            0,
-                                            0,
-                                            copy_buffer,
-                                            &resultSize);
+    int err = gnutls_x509_crt_get_dn_by_oid(x509crt_->cert, GNUTLS_OID_X520_COMMON_NAME, 0, 0, copy_buffer, &resultSize);
     return checkError(err, copy_buffer, resultSize);
 }
 
@@ -1234,12 +1203,7 @@ TlsValidator::CheckResult
 TlsValidator::getUID()
 {
     size_t resultSize = sizeof(copy_buffer);
-    int err = gnutls_x509_crt_get_dn_by_oid(x509crt_->cert,
-                                            GNUTLS_OID_LDAP_UID,
-                                            0,
-                                            0,
-                                            copy_buffer,
-                                            &resultSize);
+    int err = gnutls_x509_crt_get_dn_by_oid(x509crt_->cert, GNUTLS_OID_LDAP_UID, 0, 0, copy_buffer, &resultSize);
     return checkError(err, copy_buffer, resultSize);
 }
 
@@ -1251,12 +1215,7 @@ TlsValidator::getN()
 {
     // TODO split, cache
     size_t resultSize = sizeof(copy_buffer);
-    int err = gnutls_x509_crt_get_dn_by_oid(x509crt_->cert,
-                                            GNUTLS_OID_X520_NAME,
-                                            0,
-                                            0,
-                                            copy_buffer,
-                                            &resultSize);
+    int err = gnutls_x509_crt_get_dn_by_oid(x509crt_->cert, GNUTLS_OID_X520_NAME, 0, 0, copy_buffer, &resultSize);
     return checkError(err, copy_buffer, resultSize);
 }
 
@@ -1285,8 +1244,7 @@ TlsValidator::getO()
 TlsValidator::CheckResult
 TlsValidator::getSignatureAlgorithm()
 {
-    gnutls_sign_algorithm_t algo = (gnutls_sign_algorithm_t) gnutls_x509_crt_get_signature_algorithm(
-        x509crt_->cert);
+    gnutls_sign_algorithm_t algo = (gnutls_sign_algorithm_t) gnutls_x509_crt_get_signature_algorithm(x509crt_->cert);
 
     if (algo < 0)
         return TlsValidator::CheckResult(CheckValues::UNSUPPORTED, "");
@@ -1304,10 +1262,7 @@ TlsValidator::CheckResult
 TlsValidator::getMd5Fingerprint()
 {
     size_t resultSize = sizeof(copy_buffer);
-    int err = gnutls_x509_crt_get_fingerprint(x509crt_->cert,
-                                              GNUTLS_DIG_MD5,
-                                              copy_buffer,
-                                              &resultSize);
+    int err = gnutls_x509_crt_get_fingerprint(x509crt_->cert, GNUTLS_DIG_MD5, copy_buffer, &resultSize);
     return checkBinaryError(err, copy_buffer, resultSize);
 }
 
@@ -1320,10 +1275,7 @@ TlsValidator::CheckResult
 TlsValidator::getSha1Fingerprint()
 {
     size_t resultSize = sizeof(copy_buffer);
-    int err = gnutls_x509_crt_get_fingerprint(x509crt_->cert,
-                                              GNUTLS_DIG_SHA1,
-                                              copy_buffer,
-                                              &resultSize);
+    int err = gnutls_x509_crt_get_fingerprint(x509crt_->cert, GNUTLS_DIG_SHA1, copy_buffer, &resultSize);
     return checkBinaryError(err, copy_buffer, resultSize);
 }
 
@@ -1378,12 +1330,7 @@ TlsValidator::CheckResult
 TlsValidator::getIssuerUID()
 {
     size_t resultSize = sizeof(copy_buffer);
-    int err = gnutls_x509_crt_get_issuer_dn_by_oid(x509crt_->cert,
-                                                   GNUTLS_OID_LDAP_UID,
-                                                   0,
-                                                   0,
-                                                   copy_buffer,
-                                                   &resultSize);
+    int err = gnutls_x509_crt_get_issuer_dn_by_oid(x509crt_->cert, GNUTLS_OID_LDAP_UID, 0, 0, copy_buffer, &resultSize);
     return checkError(err, copy_buffer, resultSize);
 }
 
@@ -1394,12 +1341,7 @@ TlsValidator::CheckResult
 TlsValidator::getIssuerN()
 {
     size_t resultSize = sizeof(copy_buffer);
-    int err = gnutls_x509_crt_get_issuer_dn_by_oid(x509crt_->cert,
-                                                   GNUTLS_OID_X520_NAME,
-                                                   0,
-                                                   0,
-                                                   copy_buffer,
-                                                   &resultSize);
+    int err = gnutls_x509_crt_get_issuer_dn_by_oid(x509crt_->cert, GNUTLS_OID_X520_NAME, 0, 0, copy_buffer, &resultSize);
     return checkError(err, copy_buffer, resultSize);
 }
 
