@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "base64.h"
 #include "fileutils.h"
 #include "manager.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 
 #include <mutex>
 #include <cstdlib> // mkstemp
@@ -76,16 +76,12 @@ OutgoingFile::OutgoingFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel
 {
     std::filesystem::path fpath(info_.path);
     if (!std::filesystem::is_regular_file(fpath)) {
-        dht::ThreadPool::io().run([channel = std::move(channel_)] {
-            channel->shutdown();
-        });
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
         return;
     }
     stream_.open(fpath, std::ios::binary | std::ios::in);
     if (!stream_ || !stream_.is_open()) {
-        dht::ThreadPool::io().run([channel = std::move(channel_)] {
-            channel->shutdown();
-        });
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
         return;
     }
 }
@@ -95,9 +91,7 @@ OutgoingFile::~OutgoingFile()
     if (stream_ && stream_.is_open())
         stream_.close();
     if (channel_) {
-        dht::ThreadPool::io().run([channel = std::move(channel_)] {
-            channel->shutdown();
-        });
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
     }
 }
 
@@ -113,8 +107,7 @@ OutgoingFile::process()
         std::error_code ec;
         auto pos = start_;
         while (!stream_.eof()) {
-            stream_.read(buffer.data(),
-                         end_ > start_ ? std::min(end_ - pos, buffer.size()) : buffer.size());
+            stream_.read(buffer.data(), end_ > start_ ? std::min(end_ - pos, buffer.size()) : buffer.size());
             auto gcount = stream_.gcount();
             pos += gcount;
             channel_->write(reinterpret_cast<const uint8_t*>(buffer.data()), gcount, ec);
@@ -133,8 +126,7 @@ OutgoingFile::process()
         // will retry the transfer if they need, so we don't need to show errors.
         if (!interactionId_.empty() && !correct)
             return;
-        auto code = correct ? libjami::DataTransferEventCode::finished
-                            : libjami::DataTransferEventCode::closed_by_peer;
+        auto code = correct ? libjami::DataTransferEventCode::finished : libjami::DataTransferEventCode::closed_by_peer;
         emit(code);
     }
 }
@@ -143,8 +135,7 @@ void
 OutgoingFile::cancel()
 {
     // Remove link, not original file
-    auto path = fileutils::get_data_dir() / "conversation_data" / info_.accountId
-                / info_.conversationId / fileId_;
+    auto path = fileutils::get_data_dir() / "conversation_data" / info_.accountId / info_.conversationId / fileId_;
     if (std::filesystem::is_symlink(path))
         dhtnet::fileutils::remove(path);
     isUserCancelled_ = true;
@@ -160,8 +151,7 @@ IncomingFile::IncomingFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel
     , sha3Sum_(sha3Sum)
     , path_(info.path + ".tmp")
 {
-    stream_.open(path_,
-                 std::ios::binary | std::ios::out | std::ios::app);
+    stream_.open(path_, std::ios::binary | std::ios::out | std::ios::app);
     if (!stream_)
         return;
 
@@ -170,15 +160,13 @@ IncomingFile::IncomingFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel
 
 IncomingFile::~IncomingFile()
 {
-    if (channel_)
-        channel_->setOnRecv({});
     {
         std::lock_guard<std::mutex> lk(streamMtx_);
         if (stream_ && stream_.is_open())
             stream_.close();
     }
     if (channel_)
-        channel_->shutdown();
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
 }
 
 void
@@ -187,7 +175,7 @@ IncomingFile::cancel()
     isUserCancelled_ = true;
     emit(libjami::DataTransferEventCode::closed_by_peer);
     if (channel_)
-        channel_->shutdown();
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
 }
 
 void
@@ -195,14 +183,17 @@ IncomingFile::process()
 {
     channel_->setOnRecv([w = weak_from_this()](const uint8_t* buf, size_t len) {
         if (auto shared = w.lock()) {
-            // No need to lock, setOnRecv is resetted before closing
+            std::lock_guard<std::mutex> lk(shared->streamMtx_);
             if (shared->stream_.is_open())
                 shared->stream_.write(reinterpret_cast<const char*>(buf), len);
             shared->info_.bytesProgress = shared->stream_.tellp();
+            return (ssize_t) len;
         }
-        return len;
+        // Data received after destruction
+        JAMI_ERROR("{} bytes received after IncomingFile destruction.", len);
+        return (ssize_t) -1;
     });
-    channel_->onShutdown([w = weak_from_this()] {
+    channel_->onShutdown([w = weak_from_this()](const std::error_code& sock_ec) {
         auto shared = w.lock();
         if (!shared)
             return;
@@ -217,9 +208,15 @@ IncomingFile::process()
             if (shared->isUserCancelled_) {
                 std::filesystem::remove(shared->path_, ec);
             } else if (shared->info_.bytesProgress < shared->info_.totalSize) {
-                JAMI_WARNING("Channel for {} shut down before transfer was complete (progress: {}/{})", shared->info_.path, shared->info_.bytesProgress, shared->info_.totalSize);
+                JAMI_WARNING("Channel for {} shut down before transfer was complete (progress: {}/{})",
+                             shared->info_.path,
+                             shared->info_.bytesProgress,
+                             shared->info_.totalSize);
             } else if (shared->info_.totalSize != 0 && shared->info_.bytesProgress > shared->info_.totalSize) {
-                JAMI_WARNING("Removing {} larger than announced: {}/{}", shared->path_, shared->info_.bytesProgress, shared->info_.totalSize);
+                JAMI_WARNING("Removing {} larger than announced: {}/{}",
+                             shared->path_,
+                             shared->info_.bytesProgress,
+                             shared->info_.totalSize);
                 std::filesystem::remove(shared->path_, ec);
             } else {
                 auto sha3Sum = fileutils::sha3File(shared->path_);
@@ -227,8 +224,12 @@ IncomingFile::process()
                     JAMI_LOG("New file received: {}", shared->info_.path);
                     correct = true;
                 } else {
-                    JAMI_WARNING("Removing {} with expected size ({} bytes) but invalid sha3sum (expected: {}, actual: {})",
-                                 shared->path_, shared->info_.totalSize, shared->sha3Sum_, sha3Sum);
+                    JAMI_WARNING(
+                        "Removing {} with expected size ({} bytes) but invalid sha3sum (expected: {}, actual: {})",
+                        shared->path_,
+                        shared->info_.totalSize,
+                        shared->sha3Sum_,
+                        sha3Sum);
                     std::filesystem::remove(shared->path_, ec);
                 }
             }
@@ -245,9 +246,9 @@ IncomingFile::process()
         }
         if (shared->isUserCancelled_)
             return;
-        auto code = correct ? libjami::DataTransferEventCode::finished
-                            : libjami::DataTransferEventCode::closed_by_host;
+        auto code = correct ? libjami::DataTransferEventCode::finished : libjami::DataTransferEventCode::closed_by_host;
         shared->emit(code);
+        dht::ThreadPool::io().run([s = std::move(shared)] {});
     });
 }
 
@@ -256,18 +257,14 @@ IncomingFile::process()
 class TransferManager::Impl
 {
 public:
-    Impl(const std::string& accountId,
-         const std::string& accountUri,
-         const std::string& to,
-         const std::mt19937_64& rand)
+    Impl(const std::string& accountId, const std::string& accountUri, const std::string& to, const std::mt19937_64& rand)
         : accountId_(accountId)
         , accountUri_(accountUri)
         , to_(to)
         , rand_(rand)
     {
         if (!to_.empty()) {
-            conversationDataPath_ = fileutils::get_data_dir() / accountId_ / "conversation_data"
-                                    / to_;
+            conversationDataPath_ = fileutils::get_data_dir() / accountId_ / "conversation_data" / to_;
             dhtnet::fileutils::check_dir(conversationDataPath_);
             waitingPath_ = conversationDataPath_ / "waiting";
         }
@@ -279,8 +276,8 @@ public:
     ~Impl()
     {
         std::lock_guard lk {mapMutex_};
-        for (const auto& [channel, _of] : outgoings_) {
-            channel->shutdown();
+        for (auto& [channel, _] : outgoings_) {
+            dht::ThreadPool::io().run([c = std::move(channel)] { c->shutdown(); });
         }
         outgoings_.clear();
         incomings_.clear();
@@ -364,8 +361,8 @@ TransferManager::transferFile(const std::shared_ptr<dhtnet::ChannelSocket>& chan
             }
         });
     });
-    pimpl_->outgoings_.emplace(channel, f);
-    dht::ThreadPool::io().run([w = std::weak_ptr<OutgoingFile>(f)] {
+    auto [outFile, _] = pimpl_->outgoings_.emplace(channel, std::move(f));
+    dht::ThreadPool::io().run([w = std::weak_ptr<OutgoingFile>(outFile->second)] {
         if (auto of = w.lock())
             of->process();
     });
@@ -390,10 +387,7 @@ TransferManager::cancel(const std::string& fileId)
 }
 
 bool
-TransferManager::info(const std::string& fileId,
-                      std::string& path,
-                      int64_t& total,
-                      int64_t& progress) const noexcept
+TransferManager::info(const std::string& fileId, std::string& path, int64_t& total, int64_t& progress) const noexcept
 {
     std::unique_lock lk {pimpl_->mapMutex_};
     if (pimpl_->to_.empty())
@@ -451,14 +445,12 @@ TransferManager::onIncomingFileTransfer(const std::string& fileId,
     // Check if not already an incoming file for this id and that we are waiting this file
     auto itC = pimpl_->incomings_.find(fileId);
     if (itC != pimpl_->incomings_.end()) {
-        channel->shutdown();
+        dht::ThreadPool().io().run([channel] { channel->shutdown(); });
         return;
     }
     auto itW = pimpl_->waitingIds_.find(fileId);
     if (itW == pimpl_->waitingIds_.end()) {
-        dht::ThreadPool().io().run([channel] {
-            channel->shutdown();
-        });
+        dht::ThreadPool().io().run([channel] { channel->shutdown(); });
         return;
     }
 
@@ -518,8 +510,7 @@ TransferManager::path(const std::string& fileId) const
 }
 
 void
-TransferManager::onIncomingProfile(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
-                                   const std::string& sha3Sum)
+TransferManager::onIncomingProfile(const std::shared_ptr<dhtnet::ChannelSocket>& channel, const std::string& sha3Sum)
 {
     if (!channel)
         return;
@@ -546,7 +537,7 @@ TransferManager::onIncomingProfile(const std::shared_ptr<dhtnet::ChannelSocket>&
     // Check if not already an incoming file for this id and that we are waiting this file
     auto itV = pimpl_->vcards_.find(idx);
     if (itV != pimpl_->vcards_.end()) {
-        channel->shutdown();
+        dht::ThreadPool().io().run([channel] { channel->shutdown(); });
         return;
     }
 
@@ -599,9 +590,7 @@ TransferManager::onIncomingProfile(const std::shared_ptr<dhtnet::ChannelSocket>&
                     if (itO != pimpl->vcards_.end())
                         pimpl->vcards_.erase(itO);
                     if (code == uint32_t(libjami::DataTransferEventCode::finished)) {
-                        emitSignal<libjami::ConfigurationSignal::ProfileReceived>(accountId,
-                                                                                  uri,
-                                                                                  destPath.string());
+                        emitSignal<libjami::ConfigurationSignal::ProfileReceived>(accountId, uri, destPath.string());
                     }
                 }
             });
