@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #endif
 
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #endif
 
 #ifdef _WIN32
@@ -79,7 +79,6 @@
 #include <cstring>
 #include <cerrno>
 #include <cstddef>
-#include <ciso646>
 
 #include <pj/ctype.h>
 #include <pjlib-util/md5.h>
@@ -218,12 +217,23 @@ createFileLink(const std::filesystem::path& linkFile, const std::filesystem::pat
     if (linkFile == target)
         return true;
     std::error_code ec;
-    if (std::filesystem::exists(linkFile, ec)) {
-        if (std::filesystem::is_symlink(linkFile, ec)
-            && std::filesystem::read_symlink(linkFile, ec) == target)
+    // Use symlink_status() because exists() could return false for broken symlinks
+    auto status = std::filesystem::symlink_status(linkFile, ec);
+    if (status.type() != std::filesystem::file_type::not_found) {
+        if (status.type() == std::filesystem::file_type::symlink
+            && std::filesystem::read_symlink(linkFile, ec) == target) {
+            JAMI_DEBUG("createFileLink: {} symlink already points to target {}", linkFile, target);
             return true;
-        std::filesystem::remove(linkFile, ec);
+        }
+        // Remove any existing file or symlink before creating a new one, as create_symlink()
+        // will fail with "File exists" error if the linkFile path already exists.
+        if (status.type() == std::filesystem::file_type::regular
+            || status.type() == std::filesystem::file_type::symlink) {
+            std::filesystem::remove(linkFile, ec);
+        }
     }
+
+    // Try to create a hard link if requested; fall back to symlink on failure
     if (not hard or not createHardlink(linkFile, target))
         return createSymlink(linkFile, target);
     return true;
@@ -300,10 +310,7 @@ loadTextFile(const std::filesystem::path& path, const std::filesystem::path& def
 }
 
 void
-saveFile(const std::filesystem::path& path,
-         const uint8_t* data,
-         size_t data_size,
-         mode_t UNUSED mode)
+saveFile(const std::filesystem::path& path, const uint8_t* data, size_t data_size, mode_t UNUSED mode)
 {
     std::ofstream file(path, std::ios::trunc | std::ios::binary);
     if (!file.is_open()) {
@@ -397,8 +404,7 @@ readArchive(const std::filesystem::path& path, std::string_view scheme, const st
         if (scheme == ARCHIVE_AUTH_SCHEME_KEY) {
             try {
                 ret.salt = dht::crypto::aesGetSalt(fileContent);
-                fileContent = dht::crypto::aesDecrypt(dht::crypto::aesGetEncrypted(fileContent),
-                                                      base64::decode(pwd));
+                fileContent = dht::crypto::aesDecrypt(dht::crypto::aesGetEncrypted(fileContent), base64::decode(pwd));
             } catch (const std::exception& e) {
                 JAMI_ERROR("Error decrypting archive: {}", e.what());
                 throw;
@@ -443,10 +449,7 @@ writeArchive(const std::string& archive_str,
     } else if (scheme == ARCHIVE_AUTH_SCHEME_PASSWORD and not password.empty()) {
         // Encrypt using provided password
         try {
-            saveFile(path,
-                     dht::crypto::aesEncrypt(archiver::compress(archive_str),
-                                             password,
-                                             password_salt));
+            saveFile(path, dht::crypto::aesEncrypt(archiver::compress(archive_str), password, password_salt));
         } catch (const std::runtime_error& ex) {
             JAMI_ERROR("Export failed: {}", ex.what());
             return false;
@@ -462,7 +465,7 @@ writeArchive(const std::string& archive_str,
 }
 
 std::filesystem::path
-get_cache_dir(const char* pkg)
+get_cache_dir([[maybe_unused]] const char* pkg)
 {
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
     std::vector<std::string> paths;
@@ -538,7 +541,7 @@ get_home_dir()
 }
 
 std::filesystem::path
-get_data_dir(const char* pkg)
+get_data_dir([[maybe_unused]] const char* pkg)
 {
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
     std::vector<std::string> paths;
@@ -577,7 +580,7 @@ get_data_dir()
 }
 
 std::filesystem::path
-get_config_dir(const char* pkg)
+get_config_dir([[maybe_unused]] const char* pkg)
 {
     std::filesystem::path configdir;
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
@@ -626,8 +629,7 @@ eraseFile_win32(const std::string& path, bool dosync)
     // https://learn.microsoft.com/en-us/windows/win32/api/fileapi/nf-fileapi-deletefilea#remarks To
     // delete a read-only file, first you must remove the read-only attribute.
     SetFileAttributesA(path.c_str(), GetFileAttributesA(path.c_str()) & ~FILE_ATTRIBUTE_READONLY);
-    HANDLE h
-        = CreateFileA(path.c_str(), GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
+    HANDLE h = CreateFileA(path.c_str(), GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
     if (h == INVALID_HANDLE_VALUE) {
         JAMI_WARN("Unable to open file %s for erasing.", path.c_str());
         return false;
