@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,8 +39,7 @@ public:
         pjsip_transport base; // do not move, SHOULD be the fist member
         AbstractSIPTransport* self {nullptr};
     };
-    static_assert(std::is_standard_layout<TransportData>::value,
-                  "TransportData requires standard-layout");
+    static_assert(std::is_standard_layout<TransportData>::value, "TransportData requires standard-layout");
 
     virtual ~AbstractSIPTransport() {};
 
