@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,7 +50,8 @@ AccountManager::buildRequest(PrivateKey fDeviceKey)
         });
 }
 
-AccountManager::~AccountManager() {
+AccountManager::~AccountManager()
+{
     if (dht_)
         dht_->join();
 }
@@ -68,32 +69,23 @@ AccountManager::onSyncData(DeviceSync&& sync, bool checkDevice)
 
     // Sync known devices
     JAMI_DEBUG("[Account {}] [Contacts] received device sync data ({:d} devices, {:d} contacts, {:d} requests)",
-             accountId_,
-             sync.devices_known.size() + sync.devices.size(),
-             sync.peers.size(),
-             sync.trust_requests.size());
-    for (const auto& d : sync.devices_known) {
+               accountId_,
+               sync.devices.size(),
+               sync.peers.size(),
+               sync.trust_requests.size());
+    for (const auto& d : sync.devices) {
         findCertificate(d.first, [this, d](const std::shared_ptr<dht::crypto::Certificate>& crt) {
             if (not crt)
                 return;
             // std::lock_guard lock(deviceListMutex_);
-            foundAccountDevice(crt, d.second);
+            foundAccountDevice(crt, d.second.name);
         });
     }
-    for (const auto& d : sync.devices) {
-        findCertificate(d.second.sha1,
-                        [this, d](const std::shared_ptr<dht::crypto::Certificate>& crt) {
-                            if (not crt || crt->getLongId() != d.first)
-                                return;
-                            // std::lock_guard lock(deviceListMutex_);
-                            foundAccountDevice(crt, d.second.name);
-                        });
-    }
     // saveKnownDevices();
 
     // Sync contacts
     if (!sync.peers.empty()) {
-        for (const auto &peer: sync.peers) {
+        for (const auto& peer : sync.peers) {
             info_->contacts->updateContact(peer.first, peer.second);
         }
         info_->contacts->saveContacts();
@@ -101,18 +93,12 @@ AccountManager::onSyncData(DeviceSync&& sync, bool checkDevice)
 
     // Sync trust requests
     for (const auto& tr : sync.trust_requests)
-        info_->contacts->onTrustRequest(tr.first,
-                                        tr.second.device,
-                                        tr.second.received,
-                                        false,
-                                        tr.second.conversationId,
-                                        {});
+        info_->contacts
+            ->onTrustRequest(tr.first, tr.second.device, tr.second.received, false, tr.second.conversationId, {});
 }
 
 dht::crypto::Identity
-AccountManager::loadIdentity(const std::string& crt_path,
-                             const std::string& key_path,
-                             const std::string& key_pwd) const
+AccountManager::loadIdentity(const std::string& crt_path, const std::string& key_path, const std::string& key_pwd) const
 {
     // Return to avoid unnecessary log if certificate or key is missing. Example case: when
     // importing an account when the certificate has not been unpacked from the archive.
@@ -120,10 +106,10 @@ AccountManager::loadIdentity(const std::string& crt_path,
         return {};
 
     JAMI_DEBUG("[Account {}] [Auth] Loading certificate from '{}' and key from '{}' at {}",
-             accountId_,
-             crt_path,
-             key_path,
-             path_);
+               accountId_,
+               crt_path,
+               key_path,
+               path_);
     try {
         dht::crypto::Certificate dht_cert(fileutils::loadFile(crt_path, path_));
         dht::crypto::PrivateKey dht_key(fileutils::loadFile(key_path, path_), key_pwd);
@@ -134,7 +120,9 @@ AccountManager::loadIdentity(const std::string& crt_path,
         }
         auto& issuer = dht_cert.issuer;
         if (not issuer) {
-            JAMI_ERROR("[Account {}] [Auth] Device certificate {:s} has no issuer", accountId_, dht_cert.getId().to_view());
+            JAMI_ERROR("[Account {}] [Auth] Device certificate {:s} has no issuer",
+                       accountId_,
+                       dht_cert.getId().to_view());
             return {};
         }
         // load revocation lists for device authority (account certificate).
@@ -157,8 +145,7 @@ AccountManager::parseAnnounce(const std::string& announceBase64,
     auto announce_val = std::make_shared<dht::Value>();
     try {
         auto announce = base64::decode(announceBase64);
-        msgpack::object_handle announce_msg = msgpack::unpack((const char*) announce.data(),
-                                                              announce.size());
+        msgpack::object_handle announce_msg = msgpack::unpack((const char*) announce.data(), announce.size());
         announce_val->msgpack_unpack(announce_msg.get());
         if (not announce_val->checkSignature()) {
             JAMI_ERROR("[Auth] announce signature check failed");
@@ -167,11 +154,15 @@ AccountManager::parseAnnounce(const std::string& announceBase64,
         DeviceAnnouncement da;
         da.unpackValue(*announce_val);
         if (da.from.toString() != accountId) {
-            JAMI_ERROR("[Auth] Account ID mismatch in announce (account: {}, in announce: {})", accountId, da.from.toString());
+            JAMI_ERROR("[Auth] Account ID mismatch in announce (account: {}, in announce: {})",
+                       accountId,
+                       da.from.toString());
             return {};
         }
         if ((da.pk && da.pk->getLongId().to_view() != deviceSha256) || da.dev.toString() != deviceSha1) {
-            JAMI_ERROR("[Auth] Device ID mismatch in announce (device: {}, in announce: {})", da.pk ? deviceSha256 : deviceSha1, da.pk ? da.pk->getLongId().to_view() : da.dev.toString());
+            JAMI_ERROR("[Auth] Device ID mismatch in announce (device: {}, in announce: {})",
+                       da.pk ? deviceSha256 : deviceSha1,
+                       da.pk ? da.pk->getLongId().to_view() : da.dev.toString());
             return {};
         }
     } catch (const std::exception& e) {
@@ -206,13 +197,17 @@ AccountManager::useIdentity(const dht::crypto::Identity& identity,
     auto contactList = std::make_unique<ContactList>(accountId_, accountCertificate, path_, onChange);
     auto result = contactList->isValidAccountDevice(*identity.second);
     if (not result) {
-        JAMI_ERROR("[Account {}] [Auth] unable to use identity: device certificate chain is unable to be verified: {}", accountId_,
-                 result.toString());
+        JAMI_ERROR("[Account {}] [Auth] unable to use identity: device certificate chain is unable to be verified: {}",
+                   accountId_,
+                   result.toString());
         return nullptr;
     }
 
     auto pk = accountCertificate->getSharedPublicKey();
-    JAMI_LOG("[Account {}] [Auth] checking device receipt for account:{} device:{}", accountId_, pk->getId().toString(), identity.second->getLongId().toString());
+    JAMI_LOG("[Account {}] [Auth] checking device receipt for account:{} device:{}",
+             accountId_,
+             pk->getId().toString(),
+             identity.second->getLongId().toString());
     if (!pk->checkSignature({receipt.begin(), receipt.end()}, receiptSignature)) {
         JAMI_ERROR("[Account {}] [Auth] device receipt signature check failed", accountId_);
         return nullptr;
@@ -241,7 +236,10 @@ AccountManager::useIdentity(const dht::crypto::Identity& identity,
         return nullptr;
     }
 
-    auto announce = parseAnnounce(root["announce"].asString(), id, devicePk->getId().toString(), devicePk->getLongId().toString());
+    auto announce = parseAnnounce(root["announce"].asString(),
+                                  id,
+                                  devicePk->getId().toString(),
+                                  devicePk->getLongId().toString());
     if (not announce) {
         return nullptr;
     }
@@ -260,8 +258,7 @@ AccountManager::useIdentity(const dht::crypto::Identity& identity,
     info->username = username;
     info_ = std::move(info);
 
-    JAMI_LOG("[Account {}] [Auth] Device {} receipt checked successfully for user {}", accountId_,
-             info_->deviceId, id);
+    JAMI_LOG("[Account {}] [Auth] Device {} receipt checked successfully for user {}", accountId_, info_->deviceId, id);
     return info_.get();
 }
 
@@ -283,7 +280,7 @@ AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dc
             dht_->put(
                 h,
                 info_->announce,
-                [dcb = std::move(dcb), h, accountId=accountId_](bool ok) {
+                [dcb = std::move(dcb), h, accountId = accountId_](bool ok) {
                     if (ok)
                         JAMI_DEBUG("[Account {}] device announced at {}", accountId, h.toString());
                     // We do not care about the status, it's a permanent put, if this fail,
@@ -297,21 +294,26 @@ AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dc
         for (const auto& crl : info_->identity.second->issuer->getRevocationLists())
             dht_->put(h, crl, dht::DoneCallback {}, {}, true);
         dht_->listen<DeviceAnnouncement>(h, [this, cb = std::move(cb)](DeviceAnnouncement&& dev) {
-            findCertificate(dev.dev,
-                            [this, cb](const std::shared_ptr<dht::crypto::Certificate>& crt) {
-                                foundAccountDevice(crt);
-                                if (cb)
-                                    cb(crt);
-                            });
+            if (dev.pk) {
+                findCertificate(dev.pk->getLongId(), [this, cb](const std::shared_ptr<dht::crypto::Certificate>& crt) {
+                    foundAccountDevice(crt);
+                    if (cb)
+                        cb(crt);
+                });
+            } else {
+                findCertificate(dev.dev, [this, cb](const std::shared_ptr<dht::crypto::Certificate>& crt) {
+                    foundAccountDevice(crt);
+                    if (cb)
+                        cb(crt);
+                });
+            }
             return true;
         });
         dht_->listen<dht::crypto::RevocationList>(h, [this](dht::crypto::RevocationList&& crl) {
             if (crl.isSignedBy(*info_->identity.second->issuer)) {
                 JAMI_DEBUG("[Account {}] Found CRL for account.", accountId_);
-                certStore()
-                    .pinRevocationList(info_->accountId,
-                                       std::make_shared<dht::crypto::RevocationList>(
-                                           std::move(crl)));
+                certStore().pinRevocationList(info_->accountId,
+                                              std::make_shared<dht::crypto::RevocationList>(std::move(crl)));
             }
             return true;
         });
@@ -329,14 +331,13 @@ AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dc
         onPeerMessage(
             *v.owner,
             true,
-            [this, v](const std::shared_ptr<dht::crypto::Certificate>&,
-                      dht::InfoHash peer_account) mutable {
-                JAMI_WARNING("[Account {}] Got trust request (confirm: {}) from: {} / {}. ConversationId: {}",
-                          accountId_,
-                          v.confirm,
-                          peer_account.toString(),
-                          v.from.toString(),
-                          v.conversationId);
+            [this, v](const std::shared_ptr<dht::crypto::Certificate>&, dht::InfoHash peer_account) mutable {
+                JAMI_WARNING("[Account {}] [device {}] Got trust request (confirm: {}) from: {}. ConversationId: {}",
+                             accountId_,
+                             v.owner->getLongId().toString(),
+                             v.confirm,
+                             peer_account.toString(),
+                             v.conversationId);
                 if (info_)
                     if (info_->contacts->onTrustRequest(peer_account,
                                                         v.owner,
@@ -353,8 +354,8 @@ AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dc
                                 if (details->conversationId == conversationId) {
                                     // Here, it's possible that we already have accepted the conversation
                                     // but contact were offline and sync failed.
-                                    // So, retrigger the callback so upper layer will clone conversation if needed
-                                    // instead of getting stuck in sync.
+                                    // So, retrigger the callback so upper layer will clone conversation if
+                                    // needed instead of getting stuck in sync.
                                     info_->contacts->acceptConversation(conversationId, v.owner->getLongId().toString());
                                     return;
                                 }
@@ -399,7 +400,8 @@ AccountManager::getAccountDeviceName() const
 }
 
 bool
-AccountManager::foundPeerDevice(const std::string& accountId, const std::shared_ptr<dht::crypto::Certificate>& crt,
+AccountManager::foundPeerDevice(const std::string& accountId,
+                                const std::shared_ptr<dht::crypto::Certificate>& crt,
                                 dht::InfoHash& peer_id)
 {
     if (not crt)
@@ -431,19 +433,19 @@ AccountManager::foundPeerDevice(const std::string& accountId, const std::shared_
     }
 
     peer_id = crt->issuer->getId();
-    JAMI_LOG("[Account {}] Found peer device: {} account:{} CA:{}",
-              accountId,
-              crt->getLongId().toString(),
-              peer_id.toString(),
-              top_issuer->getId().toString());
+    JAMI_LOG("[Account {}] [device {}] Found device for peer: {} CA:{}",
+             accountId,
+             crt->getLongId().toString(),
+             peer_id.toString(),
+             top_issuer->getId().toString());
     return true;
 }
 
 void
-AccountManager::onPeerMessage(const dht::crypto::PublicKey& peer_device,
-                              bool allowPublic,
-                              std::function<void(const std::shared_ptr<dht::crypto::Certificate>& crt,
-                                                 const dht::InfoHash& peer_account)>&& cb)
+AccountManager::onPeerMessage(
+    const dht::crypto::PublicKey& peer_device,
+    bool allowPublic,
+    std::function<void(const std::shared_ptr<dht::crypto::Certificate>& crt, const dht::InfoHash& peer_account)>&& cb)
 {
     // quick check in case we already explicilty banned this device
     auto trustStatus = getCertificateStatus(peer_device.toString());
@@ -453,8 +455,7 @@ AccountManager::onPeerMessage(const dht::crypto::PublicKey& peer_device,
     }
 
     findCertificate(peer_device.getId(),
-                    [this, cb = std::move(cb), allowPublic](
-                        const std::shared_ptr<dht::crypto::Certificate>& cert) {
+                    [this, cb = std::move(cb), allowPublic](const std::shared_ptr<dht::crypto::Certificate>& cert) {
                         dht::InfoHash peer_account_id;
                         if (onPeerCertificate(cert, allowPublic, peer_account_id)) {
                             cb(cert, peer_account_id);
@@ -475,7 +476,8 @@ AccountManager::onPeerCertificate(const std::shared_ptr<dht::crypto::Certificate
 
     if (not isAllowed(*cert, allowPublic)) {
         JAMI_WARNING("[Account {}] [Auth] Discarding message from unauthorized peer {}.",
-                  accountId_, peer_account_id.toString());
+                     accountId_,
+                     peer_account_id.toString());
         return false;
     }
 
@@ -503,7 +505,7 @@ AccountManager::removeContact(const std::string& uri, bool banned)
 {
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] removeContact: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] removeContact: invalid contact URI: {}", accountId_, uri);
         return;
     }
     if (not info_) {
@@ -519,7 +521,7 @@ AccountManager::removeContactConversation(const std::string& uri)
 {
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] removeContactConversation: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] removeContactConversation: invalid contact URI: {}", accountId_, uri);
         return;
     }
     if (not info_) {
@@ -531,29 +533,29 @@ AccountManager::removeContactConversation(const std::string& uri)
 }
 
 void
-AccountManager::updateContactConversation(
-    const std::string& uri, const std::string& convId, bool added)
+AccountManager::updateContactConversation(const std::string& uri, const std::string& convId, bool added)
 {
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] updateContactConversation: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] updateContactConversation: invalid contact URI: {}", accountId_, uri);
         return;
     }
     if (not info_) {
         JAMI_ERROR("[Account {}] updateContactConversation: account not loaded", accountId_);
         return;
     }
-    info_->contacts->updateConversation(h, convId, added);
-    // Also decline trust request if there is one
-    auto req = info_->contacts->getTrustRequest(h);
-    if (req.find(libjami::Account::TrustRequest::CONVERSATIONID) != req.end()
-        && req.at(libjami::Account::TrustRequest::CONVERSATIONID) == convId) {
-        discardTrustRequest(uri);
+    if (info_->contacts->updateConversation(h, convId, added)) {
+        // Also decline trust request if there is one
+        auto req = info_->contacts->getTrustRequest(h);
+        auto convIt = req.find(libjami::Account::TrustRequest::CONVERSATIONID);
+        if (convIt != req.end() && convIt->second == convId) {
+            discardTrustRequest(uri);
+        }
+        syncDevices();
     }
-    syncDevices();
 }
 
-std::vector<std::map<std::string, std::string>>
+std::map<dht::InfoHash, Contact>
 AccountManager::getContacts(bool includeRemoved) const
 {
     if (not info_) {
@@ -561,17 +563,11 @@ AccountManager::getContacts(bool includeRemoved) const
         return {};
     }
     const auto& contacts = info_->contacts->getContacts();
-    std::vector<std::map<std::string, std::string>> ret;
-    ret.reserve(contacts.size());
-
+    std::map<dht::InfoHash, Contact> ret;
     for (const auto& c : contacts) {
         if (!c.second.isActive() && !includeRemoved && !c.second.isBanned())
             continue;
-        auto details = c.second.toMap();
-        if (not details.empty()) {
-            details["id"] = c.first.toString();
-            ret.emplace_back(std::move(details));
-        }
+        ret.emplace(c.first, c.second);
     }
     return ret;
 }
@@ -586,7 +582,7 @@ AccountManager::getContactDetails(const std::string& uri) const
     }
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] getContactDetails: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] getContactDetails: invalid contact URI: {}", accountId_, uri);
         return {};
     }
     return info_->contacts->getContactDetails(h);
@@ -601,61 +597,62 @@ AccountManager::getContactInfo(const std::string& uri) const
     }
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] getContactInfo: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] getContactInfo: invalid contact URI: {}", accountId_, uri);
         return {};
     }
     return info_->contacts->getContactInfo(h);
 }
 
 bool
-AccountManager::findCertificate(
-    const dht::InfoHash& h,
-    std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb)
+AccountManager::findCertificate(const dht::InfoHash& h,
+                                std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb)
 {
     if (auto cert = certStore().getCertificate(h.toString())) {
         if (cb)
             cb(cert);
     } else if (dht_) {
-        dht_->findCertificate(h,
-                              [cb = std::move(cb), this](
-                                  const std::shared_ptr<dht::crypto::Certificate>& crt) {
-                                  if (crt && info_) {
-                                      certStore().pinCertificate(crt);
-                                  }
-                                  if (cb)
-                                      cb(crt);
-                              });
-    }
-    return true;
-}
-
-bool
-AccountManager::findCertificate(
-    const dht::PkId& id, std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb)
-{
-    if (auto cert = certStore().getCertificate(id.toString())) {
-        if (cb)
-            cb(cert);
-    } else if (auto cert = certStore().getCertificateLegacy(fileutils::get_data_dir().string(),
-                                                            id.toString())) {
-        if (cb)
-            cb(cert);
+        dht_->findCertificate(h, [cb = std::move(cb), this](const std::shared_ptr<dht::crypto::Certificate>& crt) {
+            if (crt && info_) {
+                certStore().pinCertificate(crt);
+            }
+            if (cb)
+                cb(crt);
+        });
     } else if (cb)
         cb(nullptr);
     return true;
 }
 
 bool
-AccountManager::setCertificateStatus(const std::string& cert_id,
-                                     dhtnet::tls::TrustStore::PermissionStatus status)
+AccountManager::findCertificate(const dht::PkId& id,
+                                std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb)
+{
+    if (auto cert = certStore().getCertificate(id.toString())) {
+        if (cb)
+            cb(cert);
+    } else if (dht_) {
+        dht_->findCertificate(id, [cb = std::move(cb), this](const std::shared_ptr<dht::crypto::Certificate>& crt) {
+            if (crt && info_) {
+                certStore().pinCertificate(crt);
+            }
+            if (cb)
+                cb(crt);
+        });
+    } else if (cb)
+        cb(nullptr);
+    return true;
+}
+
+bool
+AccountManager::setCertificateStatus(const std::string& cert_id, dhtnet::tls::TrustStore::PermissionStatus status)
 {
     return info_ and info_->contacts->setCertificateStatus(cert_id, status);
 }
 
 bool
 AccountManager::setCertificateStatus(const std::shared_ptr<crypto::Certificate>& cert,
-                              dhtnet::tls::TrustStore::PermissionStatus status,
-                              bool local)
+                                     dhtnet::tls::TrustStore::PermissionStatus status,
+                                     bool local)
 {
     return info_ and info_->contacts->setCertificateStatus(cert, status, local);
 }
@@ -696,10 +693,7 @@ AccountManager::acceptTrustRequest(const std::string& from, bool includeConversa
     if (info_) {
         auto req = info_->contacts->getTrustRequest(dht::InfoHash(from));
         if (info_->contacts->acceptTrustRequest(f)) {
-            sendTrustRequestConfirm(f,
-                                    includeConversation
-                                        ? req[libjami::Account::TrustRequest::CONVERSATIONID]
-                                        : "");
+            sendTrustRequestConfirm(f, includeConversation ? req[libjami::Account::TrustRequest::CONVERSATIONID] : "");
             syncDevices();
             return true;
         }
@@ -716,9 +710,7 @@ AccountManager::discardTrustRequest(const std::string& from)
 }
 
 void
-AccountManager::sendTrustRequest(const std::string& to,
-                                 const std::string& convId,
-                                 const std::vector<uint8_t>& payload)
+AccountManager::sendTrustRequest(const std::string& to, const std::string& convId, const std::vector<uint8_t>& payload)
 {
     JAMI_WARNING("[Account {}] AccountManager::sendTrustRequest", accountId_);
     auto toH = dht::InfoHash(to);
@@ -733,28 +725,33 @@ AccountManager::sendTrustRequest(const std::string& to,
     if (info_->contacts->addContact(toH, false, convId)) {
         syncDevices();
     }
-    forEachDevice(toH,
-                  [this, toH, convId, payload](const std::shared_ptr<dht::crypto::PublicKey>& dev) {
-                      auto to = toH.toString();
-                      JAMI_WARNING("[Account {}] Sending trust request to: {:s} / {:s} of size {:d}",
-                                   accountId_, to, dev->getLongId(), payload.size());
-                      dht_->putEncrypted(dht::InfoHash::get("inbox:" + dev->getId().toString()),
-                                         dev,
-                                         dht::TrustRequest(DHT_TYPE_NS, convId, payload),
-                                         [to, size = payload.size()](bool ok) {
-                                             if (!ok)
-                                                 JAMI_ERROR("Tried to send request {:s} (size: "
-                                                            "{:d}), but put failed",
-                                                            to,
-                                                            size);
-                                         });
-                  });
+    forEachDevice(toH, [this, toH, convId, payload](const std::shared_ptr<dht::crypto::PublicKey>& dev) {
+        auto to = toH.toString();
+        JAMI_WARNING("[Account {}] [device {}] Sending trust request (size {:d}) to: {:s}",
+                     accountId_,
+                     dev->getLongId(),
+                     payload.size(),
+                     to);
+        dht_->putEncrypted(dht::InfoHash::get(concat("inbox:"sv, dev->getId().to_view())),
+                           dev,
+                           dht::TrustRequest(DHT_TYPE_NS, convId, payload),
+                           [to, size = payload.size()](bool ok) {
+                               if (!ok)
+                                   JAMI_ERROR("Tried to send request {:s} (size: "
+                                              "{:d}), but put failed",
+                                              to,
+                                              size);
+                           });
+    });
 }
 
 void
 AccountManager::sendTrustRequestConfirm(const dht::InfoHash& toH, const std::string& convId)
 {
-    JAMI_WARNING("[Account {}] AccountManager::sendTrustRequestConfirm to {} (conversation {})", accountId_, toH, convId);
+    JAMI_WARNING("[Account {}] AccountManager::sendTrustRequestConfirm to {} (conversation {})",
+                 accountId_,
+                 toH,
+                 convId);
     dht::TrustRequest answer {DHT_TYPE_NS, convId};
     answer.confirm = true;
 
@@ -762,17 +759,15 @@ AccountManager::sendTrustRequestConfirm(const dht::InfoHash& toH, const std::str
         info_->contacts->acceptConversation(convId);
 
     forEachDevice(toH, [this, toH, answer](const std::shared_ptr<dht::crypto::PublicKey>& dev) {
-        JAMI_WARNING("[Account {}] sending trust request reply: {} / {}",
-                     accountId_, toH, dev->getLongId());
+        JAMI_WARNING("[Account {}] sending trust request reply: {} / {}", accountId_, toH, dev->getLongId());
         dht_->putEncrypted(dht::InfoHash::get("inbox:" + dev->getId().toString()), dev, answer);
     });
 }
 
 void
-AccountManager::forEachDevice(
-    const dht::InfoHash& to,
-    std::function<void(const std::shared_ptr<dht::crypto::PublicKey>&)>&& op,
-    std::function<void(bool)>&& end)
+AccountManager::forEachDevice(const dht::InfoHash& to,
+                              std::function<void(const std::shared_ptr<dht::crypto::PublicKey>&)>&& op,
+                              std::function<void(bool)>&& end)
 {
     if (not dht_) {
         JAMI_ERROR("[Account {}] forEachDevice: no dht", accountId_);
@@ -796,7 +791,9 @@ AccountManager::forEachDevice(
         std::function<void(bool)> onEnd;
 
         State(dht::InfoHash to, std::string accountId)
-            : to(std::move(to)), accountId(std::move(accountId)) {}
+            : to(std::move(to))
+            , accountId(std::move(accountId))
+        {}
 
         void found(const std::shared_ptr<dht::crypto::PublicKey>& pk)
         {
@@ -830,19 +827,22 @@ AccountManager::forEachDevice(
             if (dev.from != to)
                 return true;
             state->remaining++;
-            findCertificate(dev.dev, [state](const std::shared_ptr<dht::crypto::Certificate>& cert) {
-                state->found(cert ? cert->getSharedPublicKey()
-                                  : std::shared_ptr<dht::crypto::PublicKey> {});
-            });
+            if (dev.pk) {
+                findCertificate(dev.pk->getLongId(), [state](const std::shared_ptr<dht::crypto::Certificate>& cert) {
+                    state->found(cert ? cert->getSharedPublicKey() : std::shared_ptr<dht::crypto::PublicKey> {});
+                });
+            } else {
+                findCertificate(dev.dev, [state](const std::shared_ptr<dht::crypto::Certificate>& cert) {
+                    state->found(cert ? cert->getSharedPublicKey() : std::shared_ptr<dht::crypto::PublicKey> {});
+                });
+            }
             return true;
         },
         [state](bool /*ok*/) { state->found({}); });
 }
 
 void
-AccountManager::lookupUri(const std::string& name,
-                          const std::string& defaultServer,
-                          LookupCallback cb)
+AccountManager::lookupUri(const std::string& name, const std::string& defaultServer, LookupCallback cb)
 {
     nameDir_.get().lookupUri(name, defaultServer, std::move(cb));
 }
