@@ -1,19 +1,20 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program. If not, see <https://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
+
 #pragma once
 
 #include "jamidht/conversationrepository.h"
@@ -21,6 +22,7 @@
 #include "swarm/swarm_protocol.h"
 #include "jami/conversation_interface.h"
 #include "jamidht/typers.h"
+#include "string_utils.h"
 
 #include <json/json.h>
 #include <msgpack.hpp>
@@ -41,27 +43,38 @@ class ChannelSocket;
 namespace jami {
 
 namespace ConversationMapKeys {
-static constexpr const char* ID = "id";
-static constexpr const char* CREATED = "created";
-static constexpr const char* REMOVED = "removed";
-static constexpr const char* ERASED = "erased";
-static constexpr const char* MEMBERS = "members";
-static constexpr const char* LAST_DISPLAYED = "lastDisplayed";
-static constexpr const char* PREFERENCES = "preferences";
-static constexpr const char* ACTIVE_CALLS = "activeCalls";
-static constexpr const char* HOSTED_CALLS = "hostedCalls";
-static constexpr const char* CACHED = "cached";
-static constexpr const char* RECEIVED = "received";
-static constexpr const char* DECLINED = "declined";
-static constexpr const char* FROM = "from";
-static constexpr const char* CONVERSATIONID = "conversationId";
-static constexpr const char* METADATAS = "metadatas";
+static constexpr const char* ID {"id"};
+static constexpr const char* CREATED {"created"};
+static constexpr const char* REMOVED {"removed"};
+static constexpr const char* ERASED {"erased"};
+static constexpr const char* MEMBERS {"members"};
+static constexpr const char* LAST_DISPLAYED {"lastDisplayed"};
+static constexpr const char* RECEIVED {"received"};
+static constexpr const char* DECLINED {"declined"};
+static constexpr const char* FROM {"from"};
+static constexpr const char* CONVERSATIONID {"conversationId"};
+static constexpr const char* METADATAS {"metadatas"};
 } // namespace ConversationMapKeys
 
+namespace ConversationDirectories {
+static constexpr std::string_view PREFERENCES {"preferences"};
+static constexpr std::string_view STATUS {"status"};
+static constexpr std::string_view SENDING {"sending"};
+static constexpr std::string_view FETCHED {"fetched"};
+static constexpr std::string_view ACTIVE_CALLS {"activeCalls"};
+static constexpr std::string_view HOSTED_CALLS {"hostedCalls"};
+static constexpr std::string_view CACHED {"cached"};
+} // namespace ConversationDirectories
+
 namespace ConversationPreferences {
 static constexpr const char* HOST_CONFERENCES = "hostConferences";
 }
 
+class JamiAccount;
+class ConversationRepository;
+class TransferManager;
+enum class ConversationMode;
+
 /**
  * A ConversationRequest is a request which corresponds to a trust request, but for conversations
  * It's signed by the sender and contains the members list, the conversationId, and the metadatas
@@ -90,13 +103,24 @@ struct ConversationRequest
         return m.size() == om.size() && std::equal(m.begin(), m.end(), om.begin());
     }
 
-    bool isOneToOne() const {
+    bool isOneToOne() const
+    {
         try {
             return metadatas.at("mode") == "0";
-        } catch (...) {}
+        } catch (...) {
+        }
         return true;
     }
 
+    ConversationMode mode() const
+    {
+        try {
+            return to_enum<ConversationMode>(metadatas.at("mode"));
+        } catch (...) {
+        }
+        return ConversationMode::ONE_TO_ONE;
+    }
+
     MSGPACK_DEFINE_MAP(from, conversationId, metadatas, received, declined)
 };
 
@@ -108,11 +132,13 @@ struct ConvInfo
     time_t erased {0};
     std::set<std::string> members;
     std::string lastDisplayed {};
+    ConversationMode mode {0};
 
     ConvInfo() = default;
     ConvInfo(const ConvInfo&) = default;
     ConvInfo(ConvInfo&&) = default;
-    ConvInfo(const std::string& id) : id(id) {};
+    ConvInfo(const std::string& id)
+        : id(id) {};
     explicit ConvInfo(const Json::Value& json);
 
     bool isRemoved() const { return removed >= created; }
@@ -122,19 +148,12 @@ struct ConvInfo
 
     Json::Value toJson() const;
 
-    MSGPACK_DEFINE_MAP(id, created, removed, erased, members, lastDisplayed)
+    MSGPACK_DEFINE_MAP(id, created, removed, erased, members, lastDisplayed, mode)
 };
 
-class JamiAccount;
-class ConversationRepository;
-class TransferManager;
-enum class ConversationMode;
-
 using OnPullCb = std::function<void(bool fetchOk)>;
-using OnLoadMessages
-    = std::function<void(std::vector<std::map<std::string, std::string>>&& messages)>;
-using OnLoadMessages2
-    = std::function<void(std::vector<libjami::SwarmMessage>&& messages)>;
+using OnLoadMessages = std::function<void(std::vector<std::map<std::string, std::string>>&& messages)>;
+using OnLoadMessages2 = std::function<void(std::vector<libjami::SwarmMessage>&& messages)>;
 using OnCommitCb = std::function<void(const std::string&)>;
 using OnDoneCb = std::function<void(bool, const std::string&)>;
 using OnMultiDoneCb = std::function<void(const std::vector<std::string>&)>;
@@ -142,8 +161,7 @@ using OnMembersChanged = std::function<void(const std::set<std::string>&)>;
 using DeviceId = dht::PkId;
 using GitSocketList = std::map<DeviceId, std::shared_ptr<dhtnet::ChannelSocket>>;
 using ChannelCb = std::function<bool(const std::shared_ptr<dhtnet::ChannelSocket>&)>;
-using NeedSocketCb
-    = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
+using NeedSocketCb = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
 
 class Conversation : public std::enable_shared_from_this<Conversation>
 {
@@ -151,8 +169,7 @@ public:
     Conversation(const std::shared_ptr<JamiAccount>& account,
                  ConversationMode mode,
                  const std::string& otherMember = "");
-    Conversation(const std::shared_ptr<JamiAccount>& account,
-                 const std::string& conversationId = "");
+    Conversation(const std::shared_ptr<JamiAccount>& account, const std::string& conversationId = "");
     Conversation(const std::shared_ptr<JamiAccount>& account,
                  const std::string& remoteDevice,
                  const std::string& conversationId);
@@ -173,10 +190,10 @@ public:
 
     /**
      * Bootstrap swarm manager to other peers
-     * @param onBootstraped     Callback called when connection is successfully established
-     * @param knownDevices      List of account's known devices
+     * @param onBootstrapped     Callback called when connection is established successfully
+     * @param knownDevices       List of account's known devices
      */
-    void bootstrap(std::function<void()> onBootstraped, const std::vector<DeviceId>& knownDevices);
+    void bootstrap(std::function<void()> onBootstrapped, const std::vector<DeviceId>& knownDevices);
 
     /**
      * Refresh active calls.
@@ -234,11 +251,10 @@ public:
      * @param filteredRoles    If we want to ignore some roles
      * @return members' uris
      */
-    std::set<std::string> memberUris(
-        std::string_view filter = {},
-        const std::set<MemberRole>& filteredRoles = {MemberRole::INVITED,
-                                                     MemberRole::LEFT,
-                                                     MemberRole::BANNED}) const;
+    std::set<std::string> memberUris(std::string_view filter = {},
+                                     const std::set<MemberRole>& filteredRoles = {MemberRole::INVITED,
+                                                                                  MemberRole::LEFT,
+                                                                                  MemberRole::BANNED}) const;
 
     /**
      * Get peers to sync with. This is mostly managed by the DRT
@@ -249,7 +265,7 @@ public:
      * Check if we're at least connected to one node
      * @return if the DRT is connected
      */
-    bool isBootstraped() const;
+    bool isBootstrapped() const;
     /**
      * Retrieve the uri from a deviceId
      * @note used by swarm manager (peersToSyncWith)
@@ -327,10 +343,7 @@ public:
      * @param cb        cf pull()
      * @param commitId  cf pull()
      */
-    void sync(const std::string& member,
-              const std::string& deviceId,
-              OnPullCb&& cb,
-              std::string commitId = "");
+    void sync(const std::string& member, const std::string& deviceId, OnPullCb&& cb, std::string commitId = "");
 
     /**
      * Generate an invitation to send to new contacts
@@ -477,7 +490,8 @@ public:
      * }
      */
     void updateMessageStatus(const std::map<std::string, std::map<std::string, std::string>>& messageStatus);
-    void onMessageStatusChanged(const std::function<void(const std::map<std::string, std::map<std::string, std::string>>&)>& cb);
+    void onMessageStatusChanged(
+        const std::function<void(const std::map<std::string, std::map<std::string, std::string>>&)>& cb);
     /**
      * Retrieve how many interactions there is from HEAD to interactionId
      * @param toId      "" for getting the whole history
@@ -495,9 +509,7 @@ public:
      * @param flag      To check when search is finished
      * @note triggers messagesFound
      */
-    void search(uint32_t req,
-                const Filter& filter,
-                const std::shared_ptr<std::atomic_int>& flag) const;
+    void search(uint32_t req, const Filter& filter, const std::shared_ptr<std::atomic_int>& flag) const;
     /**
      * Host a conference in the conversation
      * @note the message must have "confId"
@@ -553,7 +565,7 @@ public:
 
     /**
      * @return getAllNodes()    Nodes that are linked to the conversation
-    */
+     */
     std::vector<jami::DeviceId> getDeviceIdList() const;
 
     /**
@@ -562,19 +574,15 @@ public:
      */
     std::shared_ptr<Typers> typers() const;
 
+    void announce(const std::vector<std::map<std::string, std::string>>& commits, bool commitFromSelf = false);
+
 private:
-    std::shared_ptr<Conversation> shared()
-    {
-        return std::static_pointer_cast<Conversation>(shared_from_this());
-    }
+    std::shared_ptr<Conversation> shared() { return std::static_pointer_cast<Conversation>(shared_from_this()); }
     std::shared_ptr<Conversation const> shared() const
     {
         return std::static_pointer_cast<Conversation const>(shared_from_this());
     }
-    std::weak_ptr<Conversation> weak()
-    {
-        return std::static_pointer_cast<Conversation>(shared_from_this());
-    }
+    std::weak_ptr<Conversation> weak() { return std::static_pointer_cast<Conversation>(shared_from_this()); }
     std::weak_ptr<Conversation const> weak() const
     {
         return std::static_pointer_cast<Conversation const>(shared_from_this());
@@ -586,8 +594,7 @@ private:
      * @param ec
      * @param members       Members to try to connect
      */
-    void checkBootstrapMember(const asio::error_code& ec,
-                              std::vector<std::map<std::string, std::string>> members);
+    void checkBootstrapMember(const asio::error_code& ec, std::vector<std::map<std::string, std::string>> members);
 
     class Impl;
     std::unique_ptr<Impl> pimpl_;
