@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,8 +36,7 @@ constexpr auto NAK_PKT = "0008NAK\n"sv;
 constexpr auto DONE_CMD = "done\n"sv;
 constexpr auto WANT_CMD = "want"sv;
 constexpr auto HAVE_CMD = "have"sv;
-constexpr auto SERVER_CAPABILITIES
-    = " HEAD\0side-band side-band-64k shallow no-progress include-tag"sv;
+constexpr auto SERVER_CAPABILITIES = " HEAD\0side-band side-band-64k shallow no-progress include-tag"sv;
 
 namespace jami {
 
@@ -53,14 +52,11 @@ public:
         , repository_(repository)
         , socket_(socket)
     {
-        JAMI_DEBUG("[Account {}] [Conversation {}] [GitServer {}] created",
-            accountId_,
-            repositoryId_,
-            fmt::ptr(this));
+        JAMI_DEBUG("[Account {}] [Conversation {}] [GitServer {}] created", accountId_, repositoryId_, fmt::ptr(this));
         // Check at least if repository is correct
         git_repository* repo;
         if (git_repository_open(&repo, repository_.c_str()) != 0) {
-            socket_->shutdown();
+            dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
             return;
         }
         git_repository_free(repo);
@@ -69,24 +65,23 @@ public:
             std::lock_guard lk(destroyMtx_);
             if (isDestroying_)
                 return len;
-            if (parseOrder(std::string_view((const char*)buf, len)))
-                while(parseOrder());
+            if (parseOrder(std::string_view((const char*) buf, len)))
+                while (parseOrder())
+                    ;
             return len;
         });
     }
-    ~Impl() {
+    ~Impl()
+    {
         stop();
-        JAMI_DEBUG("[Account {}] [Conversation {}] [GitServer {}] destroyed",
-            accountId_,
-            repositoryId_,
-            fmt::ptr(this));
+        JAMI_DEBUG("[Account {}] [Conversation {}] [GitServer {}] destroyed", accountId_, repositoryId_, fmt::ptr(this));
     }
     void stop()
     {
         std::lock_guard lk(destroyMtx_);
         if (isDestroying_.exchange(true)) {
             socket_->setOnRecv({});
-            socket_->shutdown();
+            dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
         }
     }
     bool parseOrder(std::string_view buf = {});
@@ -125,7 +120,10 @@ GitServer::Impl::parseOrder(std::string_view buf)
     unsigned int pkt_len = 0;
     auto [p, ec] = std::from_chars(pkt.data(), pkt.data() + 4, pkt_len, 16);
     if (ec != std::errc()) {
-        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to parse packet size", accountId_, repositoryId_, fmt::ptr(this));
+        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to parse packet size",
+                   accountId_,
+                   repositoryId_,
+                   fmt::ptr(this));
     }
     if (pkt_len != pkt.size()) {
         // Store next packet part
@@ -142,7 +140,10 @@ GitServer::Impl::parseOrder(std::string_view buf)
         // https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L390 Do
         // not do multi-ack, just send ACK + pack file
         // In case of no common base, send NAK
-        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Peer negotiation is done. Answering to want order", accountId_, repositoryId_, fmt::ptr(this));
+        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Peer negotiation is done. Answering to want order",
+                 accountId_,
+                 repositoryId_,
+                 fmt::ptr(this));
         bool sendData;
         if (common_.empty())
             sendData = NAK();
@@ -164,11 +165,14 @@ GitServer::Impl::parseOrder(std::string_view buf)
 
     auto lim = pack.find(' ');
     auto cmd = pack.substr(0, lim);
-    auto dat = (lim < pack.size()) ? pack.substr(lim+1) : std::string_view{};
+    auto dat = (lim < pack.size()) ? pack.substr(lim + 1) : std::string_view {};
     if (cmd == UPLOAD_PACK_CMD) {
         // Cf: https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L166
         // References discovery
-        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Upload pack command detected.", accountId_, repositoryId_, fmt::ptr(this));
+        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Upload pack command detected.",
+                 accountId_,
+                 repositoryId_,
+                 fmt::ptr(this));
         auto version = 1;
         auto parameters = getParameters(dat);
         auto versionIt = parameters.find("version");
@@ -180,20 +184,33 @@ GitServer::Impl::parseOrder(std::string_view buf)
             if (ec == std::errc()) {
                 sendVersion = true;
             } else {
-                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Invalid version detected: {}", accountId_, repositoryId_, fmt::ptr(this), versionIt->second);
+                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Invalid version detected: {}",
+                             accountId_,
+                             repositoryId_,
+                             fmt::ptr(this),
+                             versionIt->second);
             }
         }
         if (version == 1) {
             sendReferenceCapabilities(sendVersion);
         } else {
-            JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] That protocol version is not yet supported (version: {:d})", accountId_, repositoryId_, fmt::ptr(this), version);
+            JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] That protocol version is not yet supported "
+                       "(version: {:d})",
+                       accountId_,
+                       repositoryId_,
+                       fmt::ptr(this),
+                       version);
         }
     } else if (cmd == WANT_CMD) {
         // Reference:
         // https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L229
         // TODO can have more want
         wantedReference_ = dat.substr(0, 40);
-        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Peer want ref: {}", accountId_, repositoryId_, fmt::ptr(this), wantedReference_);
+        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Peer want ref: {}",
+                 accountId_,
+                 repositoryId_,
+                 fmt::ptr(this),
+                 wantedReference_);
     } else if (cmd == HAVE_CMD) {
         const auto& commit = haveRefs_.emplace_back(dat.substr(0, 40));
         if (common_.empty()) {
@@ -203,10 +220,14 @@ GitServer::Impl::parseOrder(std::string_view buf)
             // TODO do not open repository every time
             git_repository* repo;
             if (git_repository_open(&repo, repository_.c_str()) != 0) {
-                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}", accountId_, repositoryId_, fmt::ptr(this), repository_);
+                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}",
+                             accountId_,
+                             repositoryId_,
+                             fmt::ptr(this),
+                             repository_);
                 return !cachedPkt_.empty();
             }
-            GitRepository rep {repo, git_repository_free};
+            GitRepository rep {repo};
             git_oid commit_id;
             if (git_oid_fromstr(&commit_id, commit.c_str()) == 0) {
                 // Reference found
@@ -214,13 +235,18 @@ GitServer::Impl::parseOrder(std::string_view buf)
             }
         }
     } else {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unwanted packet received: {}", accountId_, repositoryId_, fmt::ptr(this), pkt);
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unwanted packet received: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     pkt);
     }
     return !cachedPkt_.empty();
 }
 
 std::string
-toGitHex(size_t value) {
+toGitHex(size_t value)
+{
     return fmt::format(FMT_COMPILE("{:04x}"), value & 0x0FFFF);
 }
 
@@ -232,11 +258,15 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
     // https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L166
     git_repository* repo;
     if (git_repository_open(&repo, repository_.c_str()) != 0) {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}", accountId_, repositoryId_, fmt::ptr(this), repository_);
-        socket_->shutdown();
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
+        dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
         return;
     }
-    GitRepository rep {repo, git_repository_free};
+    GitRepository rep {repo};
 
     // Answer with the version number
     // **** When the client initially connects the server will immediately respond
@@ -244,20 +274,26 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
     std::error_code ec;
     if (sendVersion) {
         constexpr auto toSend = "000eversion 1\0"sv;
-        socket_->write(reinterpret_cast<const unsigned char*>(toSend.data()),
-                       toSend.size(),
-                       ec);
+        socket_->write(reinterpret_cast<const unsigned char*>(toSend.data()), toSend.size(), ec);
         if (ec) {
-            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}", accountId_, repositoryId_, fmt::ptr(this), repository_, ec.message());
-            socket_->shutdown();
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
+            dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
             return;
         }
     }
 
     git_oid commit_id;
     if (git_reference_name_to_id(&commit_id, rep.get(), "HEAD") < 0) {
-        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for HEAD", accountId_, repositoryId_, fmt::ptr(this));
-        socket_->shutdown();
+        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for HEAD",
+                   accountId_,
+                   repositoryId_,
+                   fmt::ptr(this));
+        dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
         return;
     }
     std::string_view currentHead = git_oid_tostr_s(&commit_id);
@@ -273,7 +309,11 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
         for (std::size_t i = 0; i < refs.count; ++i) {
             std::string_view ref = refs.strings[i];
             if (git_reference_name_to_id(&commit_id, rep.get(), ref.data()) < 0) {
-                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for {}", accountId_, repositoryId_, fmt::ptr(this), ref);
+                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for {}",
+                             accountId_,
+                             repositoryId_,
+                             fmt::ptr(this),
+                             ref);
                 continue;
             }
             currentHead = git_oid_tostr_s(&commit_id);
@@ -289,8 +329,13 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
     auto toSend = packet.str();
     socket_->write(reinterpret_cast<const unsigned char*>(toSend.data()), toSend.size(), ec);
     if (ec) {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}", accountId_, repositoryId_, fmt::ptr(this), repository_, ec.message());
-        socket_->shutdown();
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_,
+                     ec.message());
+        dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
     }
 }
 
@@ -301,11 +346,17 @@ GitServer::Impl::ACKCommon()
     // Ack common base
     if (!common_.empty()) {
         auto toSend = fmt::format(FMT_COMPILE("{:04x}ACK {} continue\n"),
-            18 + common_.size() /* size + ACK + space * 2 + continue + \n */, common_);
+                                  18 + common_.size() /* size + ACK + space * 2 + continue + \n */,
+                                  common_);
         socket_->write(reinterpret_cast<const unsigned char*>(toSend.c_str()), toSend.size(), ec);
         if (ec) {
-            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}", accountId_, repositoryId_, fmt::ptr(this), repository_, ec.message());
-            socket_->shutdown();
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
+            dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
         }
     }
 }
@@ -317,11 +368,17 @@ GitServer::Impl::ACKFirst()
     // Ack common base
     if (!common_.empty()) {
         auto toSend = fmt::format(FMT_COMPILE("{:04x}ACK {}\n"),
-            9 + common_.size() /* size + ACK + space + \n */, common_);
+                                  9 + common_.size() /* size + ACK + space + \n */,
+                                  common_);
         socket_->write(reinterpret_cast<const unsigned char*>(toSend.c_str()), toSend.size(), ec);
         if (ec) {
-            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}", accountId_, repositoryId_, fmt::ptr(this), repository_, ec.message());
-            socket_->shutdown();
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
+            dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
             return false;
         }
     }
@@ -335,8 +392,13 @@ GitServer::Impl::NAK()
     // NAK
     socket_->write(reinterpret_cast<const unsigned char*>(NAK_PKT.data()), NAK_PKT.size(), ec);
     if (ec) {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}", accountId_, repositoryId_, fmt::ptr(this), repository_, ec.message());
-        socket_->shutdown();
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_,
+                     ec.message());
+        dht::ThreadPool::io().run([socket = socket_] { socket->shutdown(); });
         return false;
     }
     return true;
@@ -347,22 +409,34 @@ GitServer::Impl::sendPackData()
 {
     git_repository* repo_ptr;
     if (git_repository_open(&repo_ptr, repository_.c_str()) != 0) {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}", accountId_, repositoryId_, fmt::ptr(this), repository_);
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
         return;
     }
-    GitRepository repo {repo_ptr, git_repository_free};
+    GitRepository repo {repo_ptr};
 
     git_packbuilder* pb_ptr;
     if (git_packbuilder_new(&pb_ptr, repo.get()) != 0) {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open packbuilder for {}", accountId_, repositoryId_, fmt::ptr(this), repository_);
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open packbuilder for {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
         return;
     }
-    GitPackBuilder pb {pb_ptr, git_packbuilder_free};
+    GitPackBuilder pb {pb_ptr};
 
     std::string fetched = wantedReference_;
     git_oid oid;
     if (git_oid_fromstr(&oid, fetched.c_str()) < 0) {
-        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for commit {}", accountId_, repositoryId_, fmt::ptr(this), fetched);
+        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for commit {}",
+                   accountId_,
+                   repositoryId_,
+                   fmt::ptr(this),
+                   fetched);
         return;
     }
 
@@ -372,7 +446,7 @@ GitServer::Impl::sendPackData()
             git_revwalk_free(walker_ptr);
         return;
     }
-    GitRevWalker walker {walker_ptr, git_revwalk_free};
+    GitRevWalker walker {walker_ptr};
     git_revwalk_sorting(walker.get(), GIT_SORT_TOPOLOGICAL);
     // Add first commit
     std::set<std::string> parents;
@@ -388,17 +462,25 @@ GitServer::Impl::sendPackData()
         if (haveCommit && parents.size() == 0 /* We are sure that all commits are there */)
             break;
         if (git_packbuilder_insert_commit(pb.get(), &oid) != 0) {
-            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open insert commit {} for {}", accountId_, repositoryId_, fmt::ptr(this), git_oid_tostr_s(&oid), repository_);
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open insert commit {} for {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         git_oid_tostr_s(&oid),
+                         repository_);
             return;
         }
 
         // Get next commit to pack
         git_commit* commit_ptr;
         if (git_commit_lookup(&commit_ptr, repo.get(), &oid) < 0) {
-            JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to look up current commit", accountId_, repositoryId_, fmt::ptr(this));
+            JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to look up current commit",
+                       accountId_,
+                       repositoryId_,
+                       fmt::ptr(this));
             return;
         }
-        GitCommit commit {commit_ptr, git_commit_free};
+        GitCommit commit {commit_ptr};
         auto parentsCount = git_commit_parentcount(commit.get());
         for (unsigned int p = 0; p < parentsCount; ++p) {
             // make sure to explore all branches
@@ -410,7 +492,11 @@ GitServer::Impl::sendPackData()
 
     git_buf data = {};
     if (git_packbuilder_write_buf(&data, pb.get()) != 0) {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to write pack data for {}", accountId_, repositoryId_, fmt::ptr(this), repository_);
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to write pack data for {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
         return;
     }
 
@@ -430,11 +516,14 @@ GitServer::Impl::sendPackData()
         toSendData.push_back(0x1);
         toSendData.insert(toSendData.end(), data.ptr + sent, data.ptr + sent + pkt_size);
 
-        socket_->write(reinterpret_cast<const unsigned char*>(toSendData.data()),
-                       toSendData.size(),
-                       ec);
+        socket_->write(reinterpret_cast<const unsigned char*>(toSendData.data()), toSendData.size(), ec);
         if (ec) {
-            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}", accountId_, repositoryId_, fmt::ptr(this), repository_, ec.message());
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
             git_buf_dispose(&data);
             return;
         }
@@ -446,7 +535,12 @@ GitServer::Impl::sendPackData()
     // And finish by a little FLUSH
     socket_->write(reinterpret_cast<const uint8_t*>(FLUSH_PKT.data()), FLUSH_PKT.size(), ec);
     if (ec) {
-        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}", accountId_, repositoryId_, fmt::ptr(this), repository_, ec.message());
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_,
+                     ec.message());
     }
 
     // Clear sent data
@@ -464,7 +558,7 @@ GitServer::Impl::getParameters(std::string_view pkt_line)
     std::string key, value;
     auto isKey = true;
     auto nullChar = 0;
-    for (auto letter: pkt_line) {
+    for (auto letter : pkt_line) {
         if (letter == '\0') {
             // parameters such as host or version are after the first \0
             if (nullChar != 0 && !key.empty()) {
