@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include "string_utils.h"
 #include "fileutils.h"
 #include "base64.h"
-#include "scheduled_executor.h"
 
 #include <asio.hpp>
 
@@ -40,7 +39,7 @@
 #include "json_utils.h"
 
 /* for Visual Studio */
-#include <ciso646>
+
 #include <sstream>
 #include <regex>
 #include <fstream>
@@ -65,9 +64,7 @@ constexpr std::chrono::seconds SAVE_INTERVAL {5};
  *  2. `(?:([^\s@]{1,64})@)?` → Optional username (max 64 chars, Unicode allowed).
  *  3. `([^\s@]+)` → Domain or standalone name (Unicode allowed, no spaces or "@").
  */
-const std::regex URI_VALIDATOR {
-    R"(^([a-zA-Z]+:(?://)?)?(?:([\w\-.~%!$&'()*+,;=]{1,64}|[^\s@]{1,64})@)?([^\s@]+)$)"
-};
+const std::regex URI_VALIDATOR {R"(^([a-zA-Z]+:(?://)?)?(?:([\w\-.~%!$&'()*+,;=]{1,64}|[^\s@]{1,64})@)?([^\s@]+)$)"};
 
 constexpr size_t MAX_RESPONSE_SIZE {1024ul * 1024};
 
@@ -107,6 +104,7 @@ NameDirectory::NameDirectory(const std::string& serverUrl, std::shared_ptr<dht::
     : serverUrl_(serverUrl)
     , logger_(std::move(l))
     , httpContext_(Manager::instance().ioContext())
+    , saveTask_(*httpContext_)
 {
     if (!serverUrl_.empty() && serverUrl_.back() == '/')
         serverUrl_.pop_back();
@@ -132,7 +130,8 @@ NameDirectory::load()
 }
 
 std::string
-canonicalName(const std::string& url) {
+canonicalName(const std::string& url)
+{
     std::string name = url;
     std::transform(name.begin(), name.end(), name.begin(), ::tolower);
     if (name.find("://") == std::string::npos)
@@ -151,9 +150,7 @@ NameDirectory::instance(const std::string& serverUrl, std::shared_ptr<dht::Logge
     auto it = instances.find(s);
     if (it != instances.end())
         return it->second;
-    auto r = instances.emplace(std::piecewise_construct,
-                               std::forward_as_tuple(s),
-                               std::forward_as_tuple(s, l));
+    auto r = instances.emplace(std::piecewise_construct, std::forward_as_tuple(s), std::forward_as_tuple(s, l));
     if (r.second)
         r.first->second.load();
     return r.first->second;
@@ -162,8 +159,8 @@ NameDirectory::instance(const std::string& serverUrl, std::shared_ptr<dht::Logge
 void
 NameDirectory::setHeaderFields(Request& request)
 {
-    request.set_header_field(restinio::http_field_t::user_agent, fmt::format("Jami ({}/{})",
-        jami::platform(), jami::arch()));
+    request.set_header_field(restinio::http_field_t::user_agent,
+                             fmt::format("Jami ({}/{})", jami::platform(), jami::arch()));
     request.set_header_field(restinio::http_field_t::accept, "*/*");
     request.set_header_field(restinio::http_field_t::content_type, "application/json");
 }
@@ -176,9 +173,7 @@ NameDirectory::lookupAddress(const std::string& addr, LookupCallback cb)
         cb(cacheResult.first, cacheResult.second, Response::found);
         return;
     }
-    auto request = std::make_shared<Request>(*httpContext_,
-                                             resolver_,
-                                             serverUrl_ + QUERY_ADDR + addr);
+    auto request = std::make_shared<Request>(*httpContext_, resolver_, serverUrl_ + QUERY_ADDR + addr);
     try {
         request->set_method(restinio::http_method_get());
         setHeaderFields(*request);
@@ -213,9 +208,9 @@ NameDirectory::lookupAddress(const std::string& addr, LookupCallback cb)
                             std::lock_guard l(cacheLock_);
                             addrCache_.emplace(name, std::pair(name, addr));
                             nameCache_.emplace(addr, std::pair(name, addr));
+                            scheduleCacheSave();
                         }
                         cb(name, addr, Response::found);
-                        scheduleCacheSave();
                     } catch (const std::exception& e) {
                         JAMI_ERROR("Error when performing address lookup: {}", e.what());
                         cb("", "", Response::error);
@@ -239,12 +234,9 @@ NameDirectory::lookupAddress(const std::string& addr, LookupCallback cb)
 }
 
 bool
-NameDirectory::verify(const std::string& name,
-                      const dht::crypto::PublicKey& pk,
-                      const std::string& signature)
+NameDirectory::verify(const std::string& name, const dht::crypto::PublicKey& pk, const std::string& signature)
 {
-    return pk.checkSignature(std::vector<uint8_t>(name.begin(), name.end()),
-                             base64::decode(signature));
+    return pk.checkSignature(std::vector<uint8_t>(name.begin(), name.end()), base64::decode(signature));
 }
 
 void
@@ -256,21 +248,17 @@ NameDirectory::lookupName(const std::string& name, LookupCallback cb)
         return;
     }
     auto encodedName = urlEncode(name);
-    auto request = std::make_shared<Request>(*httpContext_,
-                                             resolver_,
-                                             serverUrl_ + QUERY_NAME + encodedName);
+    auto request = std::make_shared<Request>(*httpContext_, resolver_, serverUrl_ + QUERY_NAME + encodedName);
     try {
         request->set_method(restinio::http_method_get());
         setHeaderFields(*request);
-        request->add_on_done_callback([this, name, cb = std::move(cb)](
-                                          const dht::http::Response& response) {
+        request->add_on_done_callback([this, name, cb = std::move(cb)](const dht::http::Response& response) {
             if (response.status_code > 400 && response.status_code < 500)
                 cb("", "", Response::notFound);
             else if (response.status_code == 400)
                 cb("", "", Response::invalidResponse);
             else if (response.status_code < 200 || response.status_code > 299) {
-                JAMI_ERROR("Name lookup for {} on {} failed with code={}",
-                           name, serverUrl_, response.status_code);
+                JAMI_ERROR("Name lookup for {} on {} failed with code={}", name, serverUrl_, response.status_code);
                 cb("", "", Response::error);
             } else {
                 try {
@@ -308,9 +296,9 @@ NameDirectory::lookupName(const std::string& name, LookupCallback cb)
                         addrCache_.emplace(name, std::pair(nameResult, addr));
                         addrCache_.emplace(nameResult, std::pair(nameResult, addr));
                         nameCache_.emplace(addr, std::pair(nameResult, addr));
+                        scheduleCacheSave();
                     }
                     cb(nameResult, addr, Response::found);
-                    scheduleCacheSave();
                 } catch (const std::exception& e) {
                     JAMI_ERROR("Error when performing name lookup: {}", e.what());
                     cb("", "", Response::error);
@@ -360,15 +348,13 @@ NameDirectory::registerName(const std::string& addr,
         }
     }
     std::string body = fmt::format("{{\"addr\":\"{}\",\"owner\":\"{}\",\"signature\":\"{}\",\"publickey\":\"{}\"}}",
-        addr,
-        owner,
-        signedname,
-        base64::encode(publickey));
+                                   addr,
+                                   owner,
+                                   signedname,
+                                   base64::encode(publickey));
 
     auto encodedName = urlEncode(name);
-    auto request = std::make_shared<Request>(*httpContext_,
-                                             resolver_,
-                                             serverUrl_ + QUERY_NAME + encodedName);
+    auto request = std::make_shared<Request>(*httpContext_, resolver_, serverUrl_ + QUERY_NAME + encodedName);
     try {
         request->set_method(restinio::http_method_post());
         setHeaderFields(*request);
@@ -376,57 +362,52 @@ NameDirectory::registerName(const std::string& addr,
 
         JAMI_WARNING("RegisterName: sending request {} {}", addr, name);
 
-        request->add_on_done_callback(
-            [this, name, addr, cb = std::move(cb)](const dht::http::Response& response) {
-                {
-                    std::lock_guard l(cacheLock_);
-                    pendingRegistrations_.erase(name);
-                }
-                if (response.status_code == 400) {
-                    cb(RegistrationResponse::incompleteRequest, name);
-                    JAMI_ERROR("RegistrationResponse::incompleteRequest");
-                } else if (response.status_code == 401) {
-                    cb(RegistrationResponse::signatureVerificationFailed, name);
-                    JAMI_ERROR("RegistrationResponse::signatureVerificationFailed");
-                } else if (response.status_code == 403) {
-                    cb(RegistrationResponse::alreadyTaken, name);
-                    JAMI_ERROR("RegistrationResponse::alreadyTaken");
-                } else if (response.status_code == 409) {
-                    cb(RegistrationResponse::alreadyTaken, name);
-                    JAMI_ERROR("RegistrationResponse::alreadyTaken");
-                } else if (response.status_code > 400 && response.status_code < 500) {
-                    cb(RegistrationResponse::alreadyTaken, name);
-                    JAMI_ERROR("RegistrationResponse::alreadyTaken");
-                } else if (response.status_code < 200 || response.status_code > 299) {
-                    cb(RegistrationResponse::error, name);
-                    JAMI_ERROR("RegistrationResponse::error");
-                } else {
-                    Json::Value json;
-                    std::string err;
-                    Json::CharReaderBuilder rbuilder;
+        request->add_on_done_callback([this, name, addr, cb = std::move(cb)](const dht::http::Response& response) {
+            {
+                std::lock_guard l(cacheLock_);
+                pendingRegistrations_.erase(name);
+            }
+            if (response.status_code == 400) {
+                cb(RegistrationResponse::incompleteRequest, name);
+                JAMI_ERROR("RegistrationResponse::incompleteRequest");
+            } else if (response.status_code == 401) {
+                cb(RegistrationResponse::signatureVerificationFailed, name);
+                JAMI_ERROR("RegistrationResponse::signatureVerificationFailed");
+            } else if (response.status_code == 403) {
+                cb(RegistrationResponse::alreadyTaken, name);
+                JAMI_ERROR("RegistrationResponse::alreadyTaken");
+            } else if (response.status_code == 409) {
+                cb(RegistrationResponse::alreadyTaken, name);
+                JAMI_ERROR("RegistrationResponse::alreadyTaken");
+            } else if (response.status_code > 400 && response.status_code < 500) {
+                cb(RegistrationResponse::alreadyTaken, name);
+                JAMI_ERROR("RegistrationResponse::alreadyTaken");
+            } else if (response.status_code < 200 || response.status_code > 299) {
+                cb(RegistrationResponse::error, name);
+                JAMI_ERROR("RegistrationResponse::error");
+            } else {
+                Json::Value json;
+                std::string err;
+                Json::CharReaderBuilder rbuilder;
 
-                    auto reader = std::unique_ptr<Json::CharReader>(rbuilder.newCharReader());
-                    if (!reader->parse(response.body.data(),
-                                       response.body.data() + response.body.size(),
-                                       &json,
-                                       &err)) {
-                        cb(RegistrationResponse::error, name);
-                        return;
-                    }
-                    auto success = json["success"].asBool();
-                    JAMI_DEBUG("Got reply for registration of {} {}: {}",
-                             name, addr, success ? "success" : "failure");
-                    if (success) {
-                        std::lock_guard l(cacheLock_);
-                        addrCache_.emplace(name, std::pair(name, addr));
-                        nameCache_.emplace(addr, std::pair(name, addr));
-                    }
-                    cb(success ? RegistrationResponse::success : RegistrationResponse::error, name);
+                auto reader = std::unique_ptr<Json::CharReader>(rbuilder.newCharReader());
+                if (!reader->parse(response.body.data(), response.body.data() + response.body.size(), &json, &err)) {
+                    cb(RegistrationResponse::error, name);
+                    return;
                 }
-                std::lock_guard lk(requestsMtx_);
-                if (auto req = response.request.lock())
-                    requests_.erase(req);
-            });
+                auto success = json["success"].asBool();
+                JAMI_DEBUG("Got reply for registration of {} {}: {}", name, addr, success ? "success" : "failure");
+                if (success) {
+                    std::lock_guard l(cacheLock_);
+                    addrCache_.emplace(name, std::pair(name, addr));
+                    nameCache_.emplace(addr, std::pair(name, addr));
+                }
+                cb(success ? RegistrationResponse::success : RegistrationResponse::error, name);
+            }
+            std::lock_guard lk(requestsMtx_);
+            if (auto req = response.request.lock())
+                requests_.erase(req);
+        });
         {
             std::lock_guard lk(requestsMtx_);
             requests_.emplace(request);
@@ -448,12 +429,12 @@ NameDirectory::registerName(const std::string& addr,
 void
 NameDirectory::scheduleCacheSave()
 {
-    // JAMI_DBG("Scheduling cache save to %s", cachePath_.c_str());
-    std::weak_ptr<Task> task = Manager::instance().scheduler().scheduleIn(
-        [this] { dht::ThreadPool::io().run([this] { saveCache(); }); }, SAVE_INTERVAL);
-    std::swap(saveTask_, task);
-    if (auto old = task.lock())
-        old->cancel();
+    saveTask_.expires_after(SAVE_INTERVAL);
+    saveTask_.async_wait([this](const asio::error_code& ec) {
+        if (ec)
+            return;
+        saveCache();
+    });
 }
 
 void
@@ -470,8 +451,7 @@ NameDirectory::saveCache()
         std::lock_guard l(cacheLock_);
         msgpack::pack(file, nameCache_);
     }
-    JAMI_DEBUG("Saved {:d} name-address mapping(s) to {}",
-             nameCache_.size(), cachePath_);
+    JAMI_DEBUG("Saved {:d} name-address mapping(s) to {}", nameCache_.size(), cachePath_);
 }
 
 void
