@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,9 +24,10 @@
 #include "call_factory.h"
 #include "preferences.h"
 #include "media/audio/audiolayer.h"
-#include "scheduled_executor.h"
 #include "gittransport.h"
+
 #include <dhtnet/certstore.h>
+#include <asio/post.hpp>
 
 #include <algorithm>
 #include <atomic>
@@ -66,6 +67,7 @@ class JamiPluginManager;
 class LIBJAMI_TEST_EXPORT Manager
 {
 private:
+    std::mutex randMutex_;
     std::mt19937_64 rand_;
 
 public:
@@ -128,8 +130,8 @@ public:
 
     void monitor(bool continuous);
 
-    std::vector<std::map<std::string, std::string>> getConnectionList(
-        const std::string& accountId, const std::string& conversationId);
+    std::vector<std::map<std::string, std::string>> getConnectionList(const std::string& accountId,
+                                                                      const std::string& conversationId);
     std::vector<std::map<std::string, std::string>> getChannelList(const std::string& accountId,
                                                                    const std::string& connectionId);
 
@@ -248,9 +250,9 @@ public:
      * @param the conference id
      */
     bool addSubCall(const std::string& accountId,
-                        const std::string& callId,
-                        const std::string& account2Id,
-                        const std::string& confId);
+                    const std::string& callId,
+                    const std::string& account2Id,
+                    const std::string& confId);
     bool addSubCall(Call& call, Conference& conference);
     void bindCallToConference(Call& call, Conference& conf);
 
@@ -275,8 +277,7 @@ public:
      * Create a conference from a list of participant
      * @param A vector containing the list of participant
      */
-    void createConfFromParticipantList(const std::string& accountId,
-                                       const std::vector<std::string>&);
+    void createConfFromParticipantList(const std::string& accountId, const std::vector<std::string>&);
 
     /**
      * Detach a participant from a conference, put the call on hold, do not hangup it
@@ -430,15 +431,10 @@ public:
      * @param accountID   The account identifier
      * @param details     The account parameters
      */
-    void setAccountDetails(const std::string& accountID,
-                           const std::map<std::string, std::string>& details);
+    void setAccountDetails(const std::string& accountID, const std::map<std::string, std::string>& details);
 
-    void setAccountActive(const std::string& accountID,
-                          bool active,
-                          bool shutdownConnections);
-    void loadAccountAndConversation(const std::string& accountId,
-                                    bool loadAll,
-                                    const std::string& convId);
+    void setAccountActive(const std::string& accountID, bool active, bool shutdownConnections);
+    void loadAccountAndConversation(const std::string& accountId, bool loadAll, const std::string& convId);
 
     std::mt19937_64 getSeededRandomEngine();
 
@@ -454,8 +450,7 @@ public:
      * @param accountId optionnal predetermined accountid to use
      * @return The account Id given to the new account
      */
-    std::string addAccount(const std::map<std::string, std::string>& details,
-                           const std::string& accountId = {});
+    std::string addAccount(const std::map<std::string, std::string>& details, const std::string& accountId = {});
 
     /**
      * Delete an existing account, unregister VoIPLink associated, and
@@ -539,6 +534,19 @@ public:
      */
     void setEchoCancellationState(const std::string& state);
 
+    /**
+     * Get the voice activity detection engine state from
+     * the current audio layer.
+     * @return bool The current state of voice activity detection
+     */
+    bool getVoiceActivityDetectionState() const;
+
+    /**
+     * Set the voice activity detection engine state in the current
+     * audio layer.
+     */
+    void setVoiceActivityDetectionState(bool state);
+
     bool isAGCEnabled() const;
     void setAGCState(bool enabled);
 
@@ -591,14 +599,14 @@ public:
      * enter BUSY state if not answered).
      * @param timeout in seconds
      */
-    void setRingingTimeout(int timeout);
+    void setRingingTimeout(std::chrono::seconds timeout);
 
     /**
      * Get ringing timeout (number of seconds after which a call will
      * enter BUSY state if not answered).
      * @return timeout in seconds
      */
-    int getRingingTimeout() const;
+    std::chrono::seconds getRingingTimeout() const;
 
     /**
      * Get the audio manager
@@ -811,17 +819,6 @@ public:
     std::shared_ptr<asio::io_context> ioContext() const;
     std::shared_ptr<dhtnet::upnp::UPnPContext> upnpContext() const;
 
-    ScheduledExecutor& scheduler();
-    std::shared_ptr<Task> scheduleTask(std::function<void()>&& task,
-                                       std::chrono::steady_clock::time_point when,
-                                       const char* filename = CURRENT_FILENAME(),
-                                       uint32_t linum = CURRENT_LINE());
-
-    std::shared_ptr<Task> scheduleTaskIn(std::function<void()>&& task,
-                                         std::chrono::steady_clock::duration timeout,
-                                         const char* filename = CURRENT_FILENAME(),
-                                         uint32_t linum = CURRENT_LINE());
-
     std::map<std::string, std::string> getNearbyPeers(const std::string& accountID);
 
 #ifdef ENABLE_VIDEO
@@ -833,8 +830,7 @@ public:
      * @param mixer true if the SinkCient is the sink of a VideoMixer node. Default is false.
      * @return share_ptr<SinkClient> A shared pointer on the created instance.
      */
-    std::shared_ptr<video::SinkClient> createSinkClient(const std::string& id = "",
-                                                        bool mixer = false);
+    std::shared_ptr<video::SinkClient> createSinkClient(const std::string& id = "", bool mixer = false);
 
     /**
      * Create a SinkClient instance for each participant in a conference, store it in an internal
@@ -844,12 +840,11 @@ public:
      * @param videoStream the the VideoFrameActiveWriter to which the sinks should be attached
      * @param sinksMap A map between sink ids and the respective shared pointer.
      */
-    void createSinkClients(
-        const std::string& callId,
-        const ConfInfo& infos,
-        const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
-        std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
-        const std::string& accountId = "");
+    void createSinkClients(const std::string& callId,
+                           const ConfInfo& infos,
+                           const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
+                           std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
+                           const std::string& accountId = "");
 
     /**
      * Return an existing SinkClient instance as a shared_ptr associated to the given identifier.
@@ -865,8 +860,7 @@ public:
     unsigned dhtLogLevel {0}; // default = disable
     AccountFactory accountFactory;
 
-    std::vector<libjami::Message> getLastMessages(const std::string& accountID,
-                                                  const uint64_t& base_timestamp);
+    std::vector<libjami::Message> getLastMessages(const std::string& accountID, const uint64_t& base_timestamp);
 
     SIPVoIPLink& sipVoIPLink() const;
 #ifdef ENABLE_PLUGIN
@@ -921,7 +915,13 @@ template<typename Callback>
 static void
 runOnMainThread(Callback&& cb)
 {
-    Manager::instance().scheduler().run([cb = std::forward<Callback>(cb)]() mutable { cb(); });
+    asio::post(*Manager::instance().ioContext(), [cb = std::forward<Callback>(cb)]() mutable {
+        try {
+            cb();
+        } catch (const std::exception& e) {
+            JAMI_ERROR("Exception running job: {}", e.what());
+        }
+    });
 }
 
 } // namespace jami
