@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 
 #include "string_utils.h"
 #include "logger.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 
 #include <iostream>
 #include <unistd.h>
@@ -119,7 +119,7 @@ MediaDemuxer::openInput(const DeviceParams& params)
 
         if (params.framerate) {
 #ifdef _WIN32
-            // On windows, framerate settings don't reduce to avrational values
+            // On Windows, framerate settings don't reduce to avrational values
             // that correspond to valid video device formats.
             // e.g. A the rational<double>(10000000, 333333) or 30.000030000
             //      will be reduced by av_reduce to 999991/33333 or 30.00003000003
@@ -190,8 +190,7 @@ MediaDemuxer::openInput(const DeviceParams& params)
     } else if (inputCtx_->nb_streams > 0 && inputCtx_->streams[0]->codecpar) {
         baseWidth_ = inputCtx_->streams[0]->codecpar->width;
         baseHeight_ = inputCtx_->streams[0]->codecpar->height;
-        JAMI_LOG("Opened input Using format {:s} and resolution {:d}x{:d}",
-                 params.format, baseWidth_, baseHeight_);
+        JAMI_LOG("Opened input using format {:s} and resolution {:d}x{:d}", params.format, baseWidth_, baseHeight_);
     }
 
     return ret;
@@ -291,10 +290,9 @@ MediaDemuxer::emitFrame(bool isAudio)
 }
 
 bool
-MediaDemuxer::pushFrameFrom(
-    std::queue<std::unique_ptr<AVPacket, std::function<void(AVPacket*)>>>& buffer,
-    bool isAudio,
-    std::mutex& mutex)
+MediaDemuxer::pushFrameFrom(std::queue<std::unique_ptr<AVPacket, std::function<void(AVPacket*)>>>& buffer,
+                            bool isAudio,
+                            std::mutex& mutex)
 {
     std::unique_lock lock(mutex);
     if (buffer.empty()) {
@@ -324,12 +322,10 @@ MediaDemuxer::pushFrameFrom(
 MediaDemuxer::Status
 MediaDemuxer::demuxe()
 {
-    auto packet = std::unique_ptr<AVPacket, std::function<void(AVPacket*)>>(av_packet_alloc(),
-                                                                            [](AVPacket* p) {
-                                                                                if (p)
-                                                                                    av_packet_free(
-                                                                                        &p);
-                                                                            });
+    auto packet = std::unique_ptr<AVPacket, std::function<void(AVPacket*)>>(av_packet_alloc(), [](AVPacket* p) {
+        if (p)
+            av_packet_free(&p);
+    });
 
     int ret = av_read_frame(inputCtx_, packet.get());
     if (ret == AVERROR(EAGAIN)) {
@@ -400,8 +396,7 @@ MediaDemuxer::decode()
         if (inputParams_.framerate.numerator() == 0)
             return Status::Success;
         rational<double> frameTime = 1e6 / inputParams_.framerate;
-        int64_t timeToSleep = lastReadPacketTime_ - av_gettime_relative()
-                              + frameTime.real<int64_t>();
+        int64_t timeToSleep = lastReadPacketTime_ - av_gettime_relative() + frameTime.real<int64_t>();
         if (timeToSleep <= 0) {
             return Status::Success;
         }
@@ -444,9 +439,7 @@ MediaDecoder::MediaDecoder(const std::shared_ptr<MediaDemuxer>& demuxer, int ind
     setupStream();
 }
 
-MediaDecoder::MediaDecoder(const std::shared_ptr<MediaDemuxer>& demuxer,
-                           int index,
-                           MediaObserver observer)
+MediaDecoder::MediaDecoder(const std::shared_ptr<MediaDemuxer>& demuxer, int index, MediaObserver observer)
     : demuxer_(demuxer)
     , avStream_(demuxer->getStream(index))
     , callback_(std::move(observer))
@@ -563,7 +556,7 @@ MediaDecoder::setupStream()
                 accel_.reset();
                 continue;
             } else {
-                // Succeed to open codec
+                // Codec opened successfully.
                 JAMI_WARN("Using hardware decoding for %s with %s",
                           avcodec_get_name(decoderCtx_->codec_id),
                           it.getName().c_str());
@@ -580,7 +573,7 @@ MediaDecoder::setupStream()
     decoderCtx_->thread_count = std::max(1u, std::min(8u, std::thread::hardware_concurrency() / 2));
     if (emulateRate_)
         JAMI_DBG() << "Using framerate emulation";
-    startTime_ = av_gettime(); // used to set pts after decoding, and for rate emulation
+    startTime_ = av_gettime(); // Used to set pts after decoding, and for rate emulation
 
 #ifdef ENABLE_HWACCEL
     if (!accel_) {
@@ -621,12 +614,12 @@ MediaDecoder::prepareDecoderContext()
             decoderCtx_->framerate = inputParams_.framerate;
         if (decoderCtx_->framerate.num == 0 || decoderCtx_->framerate.den == 0)
             decoderCtx_->framerate = {30, 1};
-    }
-    else if (avStream_->codecpar->codec_type == AVMEDIA_TYPE_AUDIO) {
+    } else if (avStream_->codecpar->codec_type == AVMEDIA_TYPE_AUDIO) {
         if (decoderCtx_->codec_id == AV_CODEC_ID_OPUS) {
             av_opt_set_int(decoderCtx_, "decode_fec", fecEnabled_ ? 1 : 0, AV_OPT_SEARCH_CHILDREN);
         }
-        auto format = libav_utils::choose_sample_fmt_default(inputDecoder_, Manager::instance().getRingBufferPool().getInternalAudioFormat().sampleFormat);
+        auto format = libav_utils::choose_sample_fmt_default(
+            inputDecoder_, Manager::instance().getRingBufferPool().getInternalAudioFormat().sampleFormat);
         decoderCtx_->sample_fmt = format;
         decoderCtx_->request_sample_fmt = format;
     }
@@ -688,11 +681,7 @@ MediaDecoder::decode(AVPacket& packet)
     frame->time_base = decoderCtx_->time_base;
     if (resolutionChangedCallback_) {
         if (decoderCtx_->width != width_ or decoderCtx_->height != height_) {
-            JAMI_DBG("Resolution changed from %dx%d to %dx%d",
-                     width_,
-                     height_,
-                     decoderCtx_->width,
-                     decoderCtx_->height);
+            JAMI_DBG("Resolution changed from %dx%d to %dx%d", width_, height_, decoderCtx_->width, decoderCtx_->height);
             width_ = decoderCtx_->width;
             height_ = decoderCtx_->height;
             resolutionChangedCallback_(width_, height_);
@@ -705,14 +694,24 @@ MediaDecoder::decode(AVPacket& packet)
         frameFinished = 1;
 
     if (frameFinished) {
-        if (inputDecoder_->type == AVMEDIA_TYPE_VIDEO)
+        if (inputDecoder_->type == AVMEDIA_TYPE_VIDEO) {
             frame->format = (AVPixelFormat) correctPixFmt(frame->format);
+        } else {
+            // It's possible (albeit rare) for avcodec_receive_frame to return a frame with
+            // unspecified channel order. This can cause issues later on in the resampler
+            // because swr_convert_frame expects the ch_layout of the input frame to match
+            // the in_ch_layout of the SwrContext, but swr_init sets in_ch_layout to a default
+            // value based on the number of channels if the channel order of the input frame
+            // is unspecified.
+            if (frame->ch_layout.order == AV_CHANNEL_ORDER_UNSPEC) {
+                av_channel_layout_default(&frame->ch_layout, frame->ch_layout.nb_channels);
+            }
+        }
         auto packetTimestamp = frame->pts; // in stream time base
         frame->pts = av_rescale_q_rnd(av_gettime() - startTime_,
                                       {1, AV_TIME_BASE},
                                       decoderCtx_->time_base,
-                                      static_cast<AVRounding>(AV_ROUND_NEAR_INF
-                                                              | AV_ROUND_PASS_MINMAX));
+                                      static_cast<AVRounding>(AV_ROUND_NEAR_INF | AV_ROUND_PASS_MINMAX));
         lastTimestamp_ = frame->pts;
         if (emulateRate_ and packetTimestamp != AV_NOPTS_VALUE) {
             auto startTime = avStream_->start_time == AV_NOPTS_VALUE ? 0 : avStream_->start_time;
