@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,14 +16,18 @@
  */
 
 #include "libav_deps.h" // MUST BE INCLUDED FIRST
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "fileutils.h"
 #include "logger.h"
 #include "manager.h"
+#include "media_buffer.h"
 #include "media_io_handle.h"
 #include "media_recorder.h"
+#include "media_filter.h"
 #include "system_codec_container.h"
 #include "video/filter_transpose.h"
+#include "audio/audio_format.h"
+
 #ifdef ENABLE_VIDEO
 #ifdef ENABLE_HWACCEL
 #include "video/accel.h"
@@ -36,6 +40,7 @@
 #include <iomanip>
 #include <sstream>
 #include <sys/types.h>
+#include <memory>
 #include <ctime>
 
 namespace jami {
@@ -61,8 +66,7 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
 {
     const MediaStream info;
 
-    StreamObserver(const MediaStream& ms,
-                   std::function<void(const std::shared_ptr<MediaFrame>&)> func)
+    StreamObserver(const MediaStream& ms, std::function<void(const std::shared_ptr<MediaFrame>&)> func)
         : info(ms)
         , cb_(func) {};
 
@@ -71,15 +75,15 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
         while (observablesFrames_.size() > 0) {
             auto obs = observablesFrames_.begin();
             (*obs)->detach(this);
-            // it should be erased from observablesFrames_ in detach. If it does not happens erase frame to avoid infinite loop.
+            // it should be erased from observablesFrames_ in detach. If it does not happens erase frame to avoid
+            // infinite loop.
             auto it = observablesFrames_.find(*obs);
             if (it != observablesFrames_.end())
                 observablesFrames_.erase(it);
         }
     };
 
-    void update(Observable<std::shared_ptr<MediaFrame>>* /*ob*/,
-                const std::shared_ptr<MediaFrame>& m) override
+    void update(Observable<std::shared_ptr<MediaFrame>>* /*ob*/, const std::shared_ptr<MediaFrame>& m) override
     {
         if (not isEnabled)
             return;
@@ -87,12 +91,11 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
         if (info.isVideo) {
             std::shared_ptr<VideoFrame> framePtr;
 #ifdef ENABLE_HWACCEL
-            auto desc = av_pix_fmt_desc_get(
-                (AVPixelFormat) (std::static_pointer_cast<VideoFrame>(m))->format());
+            auto desc = av_pix_fmt_desc_get((AVPixelFormat) (std::static_pointer_cast<VideoFrame>(m))->format());
             if (desc && (desc->flags & AV_PIX_FMT_FLAG_HWACCEL)) {
                 try {
-                    framePtr = jami::video::HardwareAccel::transferToMainMemory(
-                        *std::static_pointer_cast<VideoFrame>(m), AV_PIX_FMT_NV12);
+                    framePtr = jami::video::HardwareAccel::transferToMainMemory(*std::static_pointer_cast<VideoFrame>(m),
+                                                                                AV_PIX_FMT_NV12);
                 } catch (const std::runtime_error& e) {
                     JAMI_ERR("Accel failure: %s", e.what());
                     return;
@@ -126,10 +129,7 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
 #endif
     }
 
-    void attached(Observable<std::shared_ptr<MediaFrame>>* obs) override
-    {
-        observablesFrames_.insert(obs);
-    }
+    void attached(Observable<std::shared_ptr<MediaFrame>>* obs) override { observablesFrames_.insert(obs); }
 
     void detached(Observable<std::shared_ptr<MediaFrame>>* obs) override
     {
@@ -139,6 +139,7 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
     }
 
     bool isEnabled = false;
+
 private:
     std::function<void(const std::shared_ptr<MediaFrame>&)> cb_;
     std::unique_ptr<MediaFilter> videoRotationFilter_ {};
@@ -222,9 +223,7 @@ MediaRecorder::startRecording()
                 // get frame from queue
                 {
                     std::unique_lock lk(rec->mutexFrameBuff_);
-                    rec->cv_.wait(lk, [rec] {
-                        return rec->interrupted_ or not rec->frameBuff_.empty();
-                    });
+                    rec->cv_.wait(lk, [rec] { return rec->interrupted_ or not rec->frameBuff_.empty(); });
                     if (rec->interrupted_) {
                         break;
                     }
@@ -236,8 +235,7 @@ MediaRecorder::startRecording()
                     if (rec->encoder_ && frame && frame->pointer()) {
 #ifdef ENABLE_VIDEO
                         bool isVideo = (frame->pointer()->width > 0 && frame->pointer()->height > 0);
-                        rec->encoder_->encode(frame->pointer(),
-                                              isVideo ? rec->videoIdx_ : rec->audioIdx_);
+                        rec->encoder_->encode(frame->pointer(), isVideo ? rec->videoIdx_ : rec->audioIdx_);
 #else
                         rec->encoder_->encode(frame->pointer(), rec->audioIdx_);
 #endif // ENABLE_VIDEO
@@ -275,6 +273,7 @@ MediaRecorder::stopRecording()
 Observer<std::shared_ptr<MediaFrame>>*
 MediaRecorder::addStream(const MediaStream& ms)
 {
+    bool streamIsNew = false;
     std::lock_guard lk(mutexStreamSetup_);
     if (audioOnly_ && ms.isVideo) {
         JAMI_ERR() << "Attempting to add video stream to audio only recording";
@@ -287,23 +286,30 @@ MediaRecorder::addStream(const MediaStream& ms)
 
     auto it = streams_.find(ms.name);
     if (it == streams_.end()) {
-        auto streamPtr = std::make_unique<StreamObserver>(ms,
-                                                          [this,
-                                                           ms](const std::shared_ptr<MediaFrame>& frame) {
-                                                              onFrame(ms.name, frame);
-                                                          });
+        auto streamPtr = std::make_unique<StreamObserver>(ms, [this, ms](const std::shared_ptr<MediaFrame>& frame) {
+            onFrame(ms.name, frame);
+        });
         it = streams_.insert(std::make_pair(ms.name, std::move(streamPtr))).first;
         JAMI_LOG("[Recorder: {:p}] Recorder input #{}: {:s}", fmt::ptr(this), streams_.size(), ms.name);
+        streamIsNew = true;
     } else {
         if (ms == it->second->info)
             JAMI_LOG("[Recorder: {:p}] Recorder already has '{:s}' as input", fmt::ptr(this), ms.name);
         else {
-            it->second
-                = std::make_unique<StreamObserver>(ms,
-                                                   [this,
-                                                    ms](const std::shared_ptr<MediaFrame>& frame) {
-                                                       onFrame(ms.name, frame);
-                                                   });
+            it->second = std::make_unique<StreamObserver>(ms, [this, ms](const std::shared_ptr<MediaFrame>& frame) {
+                onFrame(ms.name, frame);
+            });
+        }
+        streamIsNew = false;
+    }
+
+    if (streamIsNew && isRecording_) {
+        if (ms.isVideo) {
+            if (!videoFilter_ || videoFilter_->needsReinitForNewStream(ms.name))
+                setupVideoOutput();
+        } else {
+            if (!audioFilter_ || audioFilter_->needsReinitForNewStream(ms.name))
+                setupAudioOutput();
         }
     }
     it->second->isEnabled = isRecording_;
@@ -321,10 +327,12 @@ MediaRecorder::removeStream(const MediaStream& ms)
     } else {
         JAMI_LOG("[Recorder: {:p}] Recorder removing '{:s}'", fmt::ptr(this), ms.name);
         streams_.erase(it);
-        if (ms.isVideo)
-            setupVideoOutput();
-        else
-            setupAudioOutput();
+        if (isRecording_) {
+            if (ms.isVideo)
+                setupVideoOutput();
+            else
+                setupAudioOutput();
+        }
     }
     return;
 }
@@ -351,13 +359,11 @@ MediaRecorder::onFrame(const std::string& name, const std::shared_ptr<MediaFrame
     const auto& ms = streams_[name]->info;
 #if defined(ENABLE_VIDEO) && defined(ENABLE_HWACCEL)
     if (ms.isVideo) {
-        auto desc = av_pix_fmt_desc_get(
-            (AVPixelFormat) (std::static_pointer_cast<VideoFrame>(frame))->format());
+        auto desc = av_pix_fmt_desc_get((AVPixelFormat) (std::static_pointer_cast<VideoFrame>(frame))->format());
         if (desc && (desc->flags & AV_PIX_FMT_FLAG_HWACCEL)) {
             try {
-                clone = video::HardwareAccel::transferToMainMemory(
-                    *std::static_pointer_cast<VideoFrame>(frame),
-                    static_cast<AVPixelFormat>(ms.format));
+                clone = video::HardwareAccel::transferToMainMemory(*std::static_pointer_cast<VideoFrame>(frame),
+                                                                   static_cast<AVPixelFormat>(ms.format));
             } catch (const std::runtime_error& e) {
                 JAMI_ERR("Accel failure: %s", e.what());
                 return;
@@ -376,28 +382,27 @@ MediaRecorder::onFrame(const std::string& name, const std::shared_ptr<MediaFrame
     clone->pointer()->pts = av_rescale_q_rnd(av_gettime() - startTimeStamp_,
                                              {1, AV_TIME_BASE},
                                              ms.timeBase,
-                                             static_cast<AVRounding>(AV_ROUND_NEAR_INF
-                                                                     | AV_ROUND_PASS_MINMAX));
+                                             static_cast<AVRounding>(AV_ROUND_NEAR_INF | AV_ROUND_PASS_MINMAX));
     std::vector<std::unique_ptr<MediaFrame>> filteredFrames;
 #ifdef ENABLE_VIDEO
     if (ms.isVideo && videoFilter_ && outputVideoFilter_) {
         std::lock_guard lk(mutexFilterVideo_);
-                videoFilter_->feedInput(clone->pointer(), name);
-        auto videoFilterOutput = videoFilter_->readOutput();
-        if (videoFilterOutput) {
-            outputVideoFilter_->feedInput(videoFilterOutput->pointer(), "input");
+        videoFilter_->feedInput(clone->pointer(), name);
+        if (auto filteredVideoOutput = videoFilter_->readOutput()) {
+            outputVideoFilter_->feedInput(filteredVideoOutput->pointer(), "input");
             while (auto fFrame = outputVideoFilter_->readOutput()) {
                 filteredFrames.emplace_back(std::move(fFrame));
             }
         }
-    } else if (audioFilter_ && outputAudioFilter_) {
+    } else if (audioFilter_ && outputAudioResampler_ && audioFrameResizer_) {
 #endif // ENABLE_VIDEO
         std::lock_guard lkA(mutexFilterAudio_);
         audioFilter_->feedInput(clone->pointer(), name);
-        auto audioFilterOutput = audioFilter_->readOutput();
-        if (audioFilterOutput) {
-            outputAudioFilter_->feedInput(audioFilterOutput->pointer(), "input");
-            filteredFrames.emplace_back(outputAudioFilter_->readOutput());
+        if (auto filteredAudioOutput = audioFilter_->readOutput()) {
+            audioFrameResizer_->enqueue(
+                outputAudioResampler_->resample(std::unique_ptr<AudioFrame>(
+                                                    static_cast<AudioFrame*>(filteredAudioOutput.release())),
+                                                AudioFormat(48000, 2)));
         }
 #ifdef ENABLE_VIDEO
     }
@@ -494,22 +499,19 @@ MediaRecorder::setupVideoOutput()
 {
     MediaStream encoderStream, peer, local, mixer;
     auto it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return pair.second->info.isVideo
-               && pair.second->info.name.find("remote") != std::string::npos;
+        return pair.second->info.isVideo && pair.second->info.name.find("remote") != std::string::npos;
     });
     if (it != streams_.end())
         peer = it->second->info;
 
     it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return pair.second->info.isVideo
-               && pair.second->info.name.find("local") != std::string::npos;
+        return pair.second->info.isVideo && pair.second->info.name.find("local") != std::string::npos;
     });
     if (it != streams_.end())
         local = it->second->info;
 
     it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return pair.second->info.isVideo
-               && pair.second->info.name.find("mixer") != std::string::npos;
+        return pair.second->info.isVideo && pair.second->info.name.find("mixer") != std::string::npos;
     });
     if (it != streams_.end())
         mixer = it->second->info;
@@ -564,14 +566,13 @@ MediaRecorder::setupVideoOutput()
 
     outputVideoFilter_.reset(new MediaFilter);
 
-    float scaledHeight = 1280 * (float)secondaryFilter.height / (float)secondaryFilter.width;
+    float scaledHeight = 1280 * (float) secondaryFilter.height / (float) secondaryFilter.width;
     std::string scaleFilter = "scale=1280:-2";
     if (scaledHeight > 720)
         scaleFilter += ",scale=-2:720";
 
     std::ostringstream f;
-    f << "[input]" << scaleFilter
-      << ",pad=1280:720:(ow-iw)/2:(oh-ih)/2,format=pix_fmts=yuv420p,fps=30";
+    f << "[input]" << scaleFilter << ",pad=1280:720:(ow-iw)/2:(oh-ih)/2,format=pix_fmts=yuv420p,fps=30";
 
     ret = outputVideoFilter_->initialize(f.str(), {secondaryFilter});
 
@@ -585,8 +586,7 @@ MediaRecorder::setupVideoOutput()
 }
 
 std::string
-MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers,
-                                const MediaStream& local) const
+MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers, const MediaStream& local) const
 {
     std::ostringstream v;
 
@@ -602,16 +602,13 @@ MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers,
 
         // NOTE -2 means preserve aspect ratio and have the new number be even
         if (needScale)
-            v << "[" << p.name << "] fps=30, scale=-2:" << newHeight
-              << " [v:m]; ";
+            v << "[" << p.name << "] fps=30, scale=-2:" << newHeight << " [v:m]; ";
         else
             v << "[" << p.name << "] fps=30 [v:m]; ";
 
-        v << "[" << local.name << "] fps=30, scale=-2:" << newHeight / 5
-          << " [v:o]; ";
+        v << "[" << local.name << "] fps=30, scale=-2:" << newHeight / 5 << " [v:o]; ";
 
-        v << "[v:m] [v:o] overlay=main_w-overlay_w:main_h-overlay_h"
-          << ", format=pix_fmts=yuv420p";
+        v << "[v:m] [v:o] overlay=main_w-overlay_w:main_h-overlay_h" << ", format=pix_fmts=yuv420p";
     } break;
     default:
         JAMI_ERR() << "Video recordings with more than 2 video streams are not supported";
@@ -653,19 +650,21 @@ MediaRecorder::setupAudioOutput()
         return;
     MediaStream secondaryFilter = audioFilter_->getOutputParams();
     secondaryFilter.name = "input";
-    if (outputAudioFilter_) {
-        outputAudioFilter_->flush();
-        outputAudioFilter_.reset();
-    }
 
-    outputAudioFilter_.reset(new MediaFilter);
-    ret = outputAudioFilter_->initialize(
-        "[input]aformat=sample_fmts=s16:sample_rates=48000:channel_layouts=stereo",
-        {secondaryFilter});
+    outputAudioResampler_ = std::make_unique<Resampler>();
+    if (!outputAudioResampler_)
+        JAMI_ERROR("Failed to initialize audio resampler");
 
-    if (ret < 0) {
-        JAMI_ERR() << "Failed to initialize output audio filter";
-    }
+    audioFrameResizer_ = std::make_unique<AudioFrameResizer>(AudioFormat(48000, 2),
+                                                             encoder_->getCurrentAudioAVCtxFrameSize(),
+                                                             [this](std::shared_ptr<AudioFrame>&& frame) {
+                                                                 std::lock_guard lk(mutexFrameBuff_);
+                                                                 frameBuff_.emplace_back(
+                                                                     std::shared_ptr<MediaFrame>(std::move(frame)));
+                                                                 cv_.notify_one();
+                                                             });
+    if (!audioFrameResizer_)
+        JAMI_ERROR("Failed to initialize audio frame resizer");
 
     return;
 }
@@ -673,12 +672,12 @@ MediaRecorder::setupAudioOutput()
 std::string
 MediaRecorder::buildAudioFilter(const std::vector<MediaStream>& peers) const
 {
-    std::string baseFilter = "aresample=osr=48000:ochl=stereo:osf=s16";
+    // resampling is handled by outputAudioResampler_
     std::ostringstream a;
 
     for (const auto& ms : peers)
         a << "[" << ms.name << "] ";
-    a << " amix=inputs=" << peers.size() << ", " << baseFilter;
+    a << " amix=inputs=" << peers.size();
     return a.str();
 }
 
@@ -696,8 +695,6 @@ MediaRecorder::flush()
         std::lock_guard lk(mutexFilterAudio_);
         if (audioFilter_)
             audioFilter_->flush();
-        if (outputAudioFilter_)
-            outputAudioFilter_->flush();
     }
     if (encoder_)
         encoder_->flush();
@@ -721,7 +718,7 @@ MediaRecorder::reset()
         {
             std::lock_guard lk2(mutexFilterAudio_);
             audioFilter_.reset();
-            outputAudioFilter_.reset();
+            outputAudioResampler_.reset();
         }
     }
     encoder_.reset();
