@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -607,13 +607,10 @@ VideoDeviceImpl::setDeviceParams(const DeviceParams& params)
     }
 }
 
-VideoDevice::VideoDevice(const std::string& id,
-                         const std::vector<std::map<std::string, std::string>>& devInfo)
+VideoDevice::VideoDevice(const std::string& id, const std::vector<std::map<std::string, std::string>>& devInfo)
     : id_(id)
 {
-    deviceImpl_ = std::make_shared<VideoDeviceImpl>(id,
-                                                    devInfo.empty() ? id
-                                                                    : devInfo.at(0).at("devPath"));
+    deviceImpl_ = std::make_shared<VideoDeviceImpl>(id, devInfo.empty() ? id : devInfo.at(0).at("devPath"));
     name = deviceImpl_->name;
 }
 
