@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include "media_const.h"
 #include "manager.h"
 #include "client/videomanager.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "sinkclient.h"
 #include "logger.h"
 #include "media/media_buffer.h"
@@ -139,9 +139,7 @@ void
 VideoInput::setRotation(int angle)
 {
     std::shared_ptr<AVBufferRef> displayMatrix {av_buffer_alloc(sizeof(int32_t) * 9),
-                                                [](AVBufferRef* buf) {
-                                                    av_buffer_unref(&buf);
-                                                }};
+                                                [](AVBufferRef* buf) { av_buffer_unref(&buf); }};
     if (displayMatrix) {
         av_display_rotation_set(reinterpret_cast<int32_t*>(displayMatrix->data), angle);
         displayMatrix_ = std::move(displayMatrix);
@@ -225,22 +223,16 @@ VideoInput::flushBuffers()
 }
 
 void
-VideoInput::configureFilePlayback(const std::string&,
-                                  std::shared_ptr<MediaDemuxer>& demuxer,
-                                  int index)
+VideoInput::configureFilePlayback(const std::string&, std::shared_ptr<MediaDemuxer>& demuxer, int index)
 {
     deleteDecoder();
     clearOptions();
 
-    auto decoder = std::make_unique<MediaDecoder>(demuxer,
-                                                  index,
-                                                  [this](std::shared_ptr<MediaFrame>&& frame) {
-                                                      publishFrame(
-                                                          std::static_pointer_cast<VideoFrame>(
-                                                              frame));
-                                                  });
-    decoder->setInterruptCallback(
-        [](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); }, this);
+    auto decoder = std::make_unique<MediaDecoder>(demuxer, index, [this](std::shared_ptr<MediaFrame>&& frame) {
+        publishFrame(std::static_pointer_cast<VideoFrame>(frame));
+    });
+    decoder->setInterruptCallback([](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); },
+                                  this);
     decoder->emulateRate();
 
     decoder_ = std::move(decoder);
@@ -293,19 +285,19 @@ VideoInput::createDecoder()
         return;
     }
 
-    auto decoder = std::make_unique<MediaDecoder>(
-        [this](const std::shared_ptr<MediaFrame>& frame) mutable {
-            publishFrame(std::static_pointer_cast<VideoFrame>(frame));
-        });
+    auto decoder = std::make_unique<MediaDecoder>([this](const std::shared_ptr<MediaFrame>& frame) mutable {
+        publishFrame(std::static_pointer_cast<VideoFrame>(frame));
+    });
 
     if (emulateRate_)
         decoder->emulateRate();
 
-    decoder->setInterruptCallback(
-        [](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); }, this);
+    decoder->setInterruptCallback([](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); },
+                                  this);
 
     bool ready = false, restartSink = false;
-    if ((decOpts_.format == "x11grab" || decOpts_.format == "dxgigrab" || decOpts_.format == "pipewiregrab") && !decOpts_.is_area) {
+    if ((decOpts_.format == "x11grab" || decOpts_.format == "dxgigrab" || decOpts_.format == "pipewiregrab")
+        && !decOpts_.is_area) {
         decOpts_.width = 0;
         decOpts_.height = 0;
     }
@@ -733,13 +725,7 @@ VideoInput::getInfo() const
     }
     auto opts = futureDecOpts_.get();
     rational<int> fr(opts.framerate.numerator(), opts.framerate.denominator());
-    return MediaStream("v:local",
-                       av_get_pix_fmt(opts.pixel_format.c_str()),
-                       1 / fr,
-                       opts.width,
-                       opts.height,
-                       0,
-                       fr);
+    return MediaStream("v:local", av_get_pix_fmt(opts.pixel_format.c_str()), 1 / fr, opts.width, opts.height, 0, fr);
 }
 
 void
