@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -373,25 +373,24 @@ AudioPreference::createAudioLayer()
 std::vector<std::string>
 AudioPreference::getSupportedAudioManagers()
 {
-    return
-    {
+    return {
 #if HAVE_OPENSL
         OPENSL_API_STR,
 #endif
 #if HAVE_ALSA
-            ALSA_API_STR,
+        ALSA_API_STR,
 #endif
 #if HAVE_PULSE
-            PULSEAUDIO_API_STR,
+        PULSEAUDIO_API_STR,
 #endif
 #if HAVE_JACK
-            JACK_API_STR,
+        JACK_API_STR,
 #endif
 #if HAVE_COREAUDIO
-            COREAUDIO_API_STR,
+        COREAUDIO_API_STR,
 #endif
 #if HAVE_PORTAUDIO
-            PORTAUDIO_API_STR,
+        PORTAUDIO_API_STR,
 #endif
     };
 }
