@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,8 +50,7 @@ static constexpr int POOL_INCREMENT_SIZE = POOL_INITIAL_SIZE;
 static std::map<MediaDirection, const char*> DIRECTION_STR {{MediaDirection::SENDRECV, "sendrecv"},
                                                             {MediaDirection::SENDONLY, "sendonly"},
                                                             {MediaDirection::RECVONLY, "recvonly"},
-                                                            {MediaDirection::INACTIVE, "inactive"},
-                                                            {MediaDirection::UNKNOWN, "unknown"}};
+                                                            {MediaDirection::INACTIVE, "inactive"}};
 
 Sdp::Sdp(const std::string& id)
     : memPool_(nullptr, [](pj_pool_t* pool) { pj_pool_release(pool); })
@@ -146,8 +145,7 @@ Sdp::generateSdesAttribute()
     // generate keys
     randomFill(keyAndSalt);
 
-    std::string crypto_attr = "1 "s + jami::CryptoSuites[cryptoSuite].name
-                              + " inline:" + base64::encode(keyAndSalt);
+    std::string crypto_attr = "1 "s + jami::CryptoSuites[cryptoSuite].name + " inline:" + base64::encode(keyAndSalt);
     pj_str_t val {sip_utils::CONST_PJ_STR(crypto_attr)};
     return pjmedia_sdp_attr_create(memPool_.get(), "crypto", &val);
 }
@@ -183,39 +181,24 @@ Sdp::mediaDirection(const MediaAttribute& mediaAttr)
 MediaDirection
 Sdp::getMediaDirection(pjmedia_sdp_media* media)
 {
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::SENDRECV],
-                               nullptr)
-        != nullptr) {
-        return MediaDirection::SENDRECV;
-    }
-
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::SENDONLY],
-                               nullptr)
+    if (pjmedia_sdp_attr_find2(media->attr_count, media->attr, DIRECTION_STR[MediaDirection::SENDONLY], nullptr)
         != nullptr) {
         return MediaDirection::SENDONLY;
     }
 
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::RECVONLY],
-                               nullptr)
+    if (pjmedia_sdp_attr_find2(media->attr_count, media->attr, DIRECTION_STR[MediaDirection::RECVONLY], nullptr)
         != nullptr) {
         return MediaDirection::RECVONLY;
     }
 
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::INACTIVE],
-                               nullptr)
+    if (pjmedia_sdp_attr_find2(media->attr_count, media->attr, DIRECTION_STR[MediaDirection::INACTIVE], nullptr)
         != nullptr) {
         return MediaDirection::INACTIVE;
     }
 
-    return MediaDirection::UNKNOWN;
+    // According to RFC 3264 (https://datatracker.ietf.org/doc/html/rfc3264#section-5.1),
+    // "a=sendrecv" is the default media direction attribute.
+    return MediaDirection::SENDRECV;
 }
 
 MediaTransport
@@ -271,8 +254,7 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
     med->desc.port_count = 1;
 
     // Set the transport protocol of the media
-    med->desc.transport = secure ? sip_utils::CONST_PJ_STR("RTP/SAVP")
-                                 : sip_utils::CONST_PJ_STR("RTP/AVP");
+    med->desc.transport = secure ? sip_utils::CONST_PJ_STR("RTP/SAVP") : sip_utils::CONST_PJ_STR("RTP/AVP");
 
     unsigned dynamic_payload = 96;
 
@@ -285,8 +267,7 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
         unsigned payload;
 
         if (type == MediaType::MEDIA_AUDIO) {
-            auto accountAudioCodec = std::static_pointer_cast<SystemAudioCodecInfo>(
-                audio_codec_list_[i]);
+            auto accountAudioCodec = std::static_pointer_cast<SystemAudioCodecInfo>(audio_codec_list_[i]);
             payload = accountAudioCodec->payloadType;
             enc_name = accountAudioCodec->name;
 
@@ -326,15 +307,12 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
         if (enc_name == "H264") {
             // FIXME: this should not be hardcoded, it will determine what profile and level
             // our peer will send us
-            const auto accountVideoCodec = std::static_pointer_cast<SystemVideoCodecInfo>(
-                video_codec_list_[i]);
+            const auto accountVideoCodec = std::static_pointer_cast<SystemVideoCodecInfo>(video_codec_list_[i]);
             const auto& profileLevelID = accountVideoCodec->parameters.empty()
                                              ? libav_utils::DEFAULT_H264_PROFILE_LEVEL_ID
                                              : accountVideoCodec->parameters;
             auto value = fmt::format("fmtp:{} {}", payload, profileLevelID);
-            med->attr[med->attr_count++] = pjmedia_sdp_attr_create(memPool_.get(),
-                                                                   value.c_str(),
-                                                                   NULL);
+            med->attr[med->attr_count++] = pjmedia_sdp_attr_create(memPool_.get(), value.c_str(), NULL);
         }
 #endif
     }
@@ -397,9 +375,7 @@ void
 Sdp::setTelephoneEventRtpmap(pjmedia_sdp_media* med)
 {
     ++med->desc.fmt_count;
-    pj_strdup2(memPool_.get(),
-               &med->desc.fmt[med->desc.fmt_count - 1],
-               std::to_string(telephoneEventPayload_).c_str());
+    pj_strdup2(memPool_.get(), &med->desc.fmt[med->desc.fmt_count - 1], std::to_string(telephoneEventPayload_).c_str());
 
     pjmedia_sdp_attr* attr_rtpmap = static_cast<pjmedia_sdp_attr*>(
         pj_pool_zalloc(memPool_.get(), sizeof(pjmedia_sdp_attr)));
@@ -417,8 +393,7 @@ Sdp::setTelephoneEventRtpmap(pjmedia_sdp_media* med)
 }
 
 void
-Sdp::setLocalMediaCapabilities(MediaType type,
-                               const std::vector<std::shared_ptr<SystemCodecInfo>>& selectedCodecs)
+Sdp::setLocalMediaCapabilities(MediaType type, const std::vector<std::shared_ptr<SystemCodecInfo>>& selectedCodecs)
 {
     switch (type) {
     case MediaType::MEDIA_AUDIO:
@@ -462,13 +437,11 @@ void
 Sdp::printSession(const pjmedia_sdp_session* session, const char* header, SdpDirection direction)
 {
     static constexpr size_t BUF_SZ = 4095;
-    std::unique_ptr<pj_pool_t, decltype(pj_pool_release)&>
-        tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
-                                "printSdp",
-                                BUF_SZ,
-                                BUF_SZ,
-                                nullptr),
-                 pj_pool_release);
+    sip_utils::PoolPtr tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
+                                               "printSdp",
+                                               BUF_SZ,
+                                               BUF_SZ,
+                                               nullptr));
 
     auto cloned_session = pjmedia_sdp_session_clone(tmpPool_.get(), session);
     if (!cloned_session) {
@@ -488,8 +461,7 @@ Sdp::printSession(const pjmedia_sdp_session* session, const char* header, SdpDir
         return;
     }
 
-    JAMI_LOG("[SDP {}] {}\n{:s}", getSdpDirectionStr(direction), header,
-        std::string_view(buffer.data(), size));
+    JAMI_LOG("[SDP {}] {}\n{:s}", getSdpDirectionStr(direction), header, std::string_view(buffer.data(), size));
 }
 
 void
@@ -563,8 +535,7 @@ Sdp::createOffer(const std::vector<MediaAttribute>& mediaList)
         return false;
     }
 
-    if (pjmedia_sdp_neg_create_w_local_offer(memPool_.get(), localSession_, &negotiator_)
-        != PJ_SUCCESS) {
+    if (pjmedia_sdp_neg_create_w_local_offer(memPool_.get(), localSession_, &negotiator_) != PJ_SUCCESS) {
         JAMI_ERR("Failed to create an initial SDP negotiator");
         return false;
     }
@@ -590,9 +561,7 @@ Sdp::processIncomingOffer(const std::vector<MediaAttribute>& mediaList)
     if (not remoteSession_)
         return false;
 
-    JAMI_DEBUG("Processing received offer for [{:s}] with {:d} media",
-             sessionName_,
-             mediaList.size());
+    JAMI_DEBUG("Processing received offer for [{:s}] with {:d} media", sessionName_, mediaList.size());
 
     printSession(remoteSession_, "Remote session:", SdpDirection::OFFER);
 
@@ -617,10 +586,7 @@ Sdp::processIncomingOffer(const std::vector<MediaAttribute>& mediaList)
         return false;
     }
 
-    if (pjmedia_sdp_neg_create_w_remote_offer(memPool_.get(),
-                                              localSession_,
-                                              remoteSession_,
-                                              &negotiator_)
+    if (pjmedia_sdp_neg_create_w_remote_offer(memPool_.get(), localSession_, remoteSession_, &negotiator_)
         != PJ_SUCCESS) {
         JAMI_ERR("Failed to initialize media negotiation");
         return false;
@@ -661,8 +627,7 @@ Sdp::startNegotiation()
         printSession(active_local, "Local active session:", sdpDirection_);
     }
 
-    if (pjmedia_sdp_neg_get_active_remote(negotiator_, &active_remote) != PJ_SUCCESS
-        or active_remote == nullptr) {
+    if (pjmedia_sdp_neg_get_active_remote(negotiator_, &active_remote) != PJ_SUCCESS or active_remote == nullptr) {
         JAMI_ERR("Unable to retrieve remote active session");
         return false;
     }
@@ -678,13 +643,8 @@ std::string
 Sdp::getFilteredSdp(const pjmedia_sdp_session* session, unsigned media_keep, unsigned pt_keep)
 {
     static constexpr size_t BUF_SZ = 4096;
-    std::unique_ptr<pj_pool_t, decltype(pj_pool_release)&>
-        tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
-                                "tmpSdp",
-                                BUF_SZ,
-                                BUF_SZ,
-                                nullptr),
-                 pj_pool_release);
+    sip_utils::PoolPtr tmpPool_(
+        pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory, "tmpSdp", BUF_SZ, BUF_SZ, nullptr));
     auto cloned = pjmedia_sdp_session_clone(tmpPool_.get(), session);
     if (!cloned) {
         JAMI_ERR("Unable to clone SDP");
@@ -729,9 +689,7 @@ Sdp::getFilteredSdp(const pjmedia_sdp_session* session, unsigned media_keep, uns
             while (auto attr = pjmedia_sdp_attr_find2(media->attr_count, media->attr, "fmt", &pt))
                 pjmedia_sdp_attr_remove(&media->attr_count, media->attr, attr);
 
-            std::move(media->desc.fmt + c + 1,
-                      media->desc.fmt + media->desc.fmt_count,
-                      media->desc.fmt + c);
+            std::move(media->desc.fmt + c + 1, media->desc.fmt + media->desc.fmt_count, media->desc.fmt + c);
             media->desc.fmt_count--;
             c--;
         }
@@ -811,25 +769,18 @@ Sdp::getMediaDescriptions(const pjmedia_sdp_session* session, bool remote) const
                                                  nullptr);
 
         descr.direction_ = getMediaDirection(media);
-        if (descr.direction_ == MediaDirection::UNKNOWN) {
-            JAMI_ERR("Did not find media direction attribute in remote SDP");
-        }
 
         // get codecs infos
         for (unsigned j = 0; j < media->desc.fmt_count; j++) {
-            const auto rtpMapAttribute = pjmedia_sdp_media_find_attr(media,
-                                                                     &STR_RTPMAP,
-                                                                     &media->desc.fmt[j]);
+            const auto rtpMapAttribute = pjmedia_sdp_media_find_attr(media, &STR_RTPMAP, &media->desc.fmt[j]);
             if (!rtpMapAttribute) {
                 JAMI_ERR("Unable to find rtpmap attribute");
                 descr.enabled = false;
                 continue;
             }
             pjmedia_sdp_rtpmap rtpmap;
-            if (pjmedia_sdp_attr_get_rtpmap(rtpMapAttribute, &rtpmap) != PJ_SUCCESS
-                || rtpmap.enc_name.slen == 0) {
-                JAMI_ERROR("Unable to find payload type {} in SDP",
-                    sip_utils::as_view(media->desc.fmt[j]));
+            if (pjmedia_sdp_attr_get_rtpmap(rtpMapAttribute, &rtpmap) != PJ_SUCCESS || rtpmap.enc_name.slen == 0) {
+                JAMI_ERROR("Unable to find payload type {} in SDP", sip_utils::as_view(media->desc.fmt[j]));
                 descr.enabled = false;
                 continue;
             }
@@ -843,9 +794,7 @@ Sdp::getMediaDescriptions(const pjmedia_sdp_session* session, bool remote) const
             }
             descr.payload_type = pj_strtoul(&rtpmap.pt);
             if (descr.type == MEDIA_VIDEO) {
-                const auto fmtpAttr = pjmedia_sdp_media_find_attr(media,
-                                                                  &STR_FMTP,
-                                                                  &media->desc.fmt[j]);
+                const auto fmtpAttr = pjmedia_sdp_media_find_attr(media, &STR_FMTP, &media->desc.fmt[j]);
                 // descr.bitrate = getOutgoingVideoField(codec, "bitrate");
                 if (fmtpAttr && fmtpAttr->value.ptr && fmtpAttr->value.slen) {
                     const auto& v = fmtpAttr->value;
@@ -889,8 +838,7 @@ void
 Sdp::addIceCandidates(unsigned media_index, const std::vector<std::string>& cands)
 {
     if (media_index >= localSession_->media_count) {
-        JAMI_ERR("addIceCandidates failed: unable to access media#%u (may be deactivated)",
-                 media_index);
+        JAMI_ERR("addIceCandidates failed: unable to access media#%u (may be deactivated)", media_index);
         return;
     }
 
@@ -919,8 +867,7 @@ Sdp::getIceCandidates(unsigned media_index) const
         return {};
     }
     if (media_index >= remoteSession->media_count || media_index >= localSession->media_count) {
-        JAMI_ERR("getIceCandidates failed: unable to access media#%u (may be deactivated)",
-                 media_index);
+        JAMI_ERR("getIceCandidates failed: unable to access media#%u (may be deactivated)", media_index);
         return {};
     }
     auto media = remoteSession->media[media_index];
@@ -1062,8 +1009,7 @@ Sdp::getMediaAttributeListFromSdp(const pjmedia_sdp_session* sdpSession, bool ig
 
         // Get mute state.
         auto direction = getMediaDirection(media);
-        mediaAttr.muted_ = direction != MediaDirection::SENDRECV
-                           and direction != MediaDirection::SENDONLY;
+        mediaAttr.muted_ = direction != MediaDirection::SENDRECV and direction != MediaDirection::SENDONLY;
 
         // Get transport.
         auto transp = getMediaTransport(media);
