@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include "sip/sipaccountbase.h"
 #include "sip/siptransport.h"
 #include "noncopyable.h"
-#include "ring_types.h" // enable_if_base_of
 #include "sipaccount_config.h"
 
 #include <pjsip/sip_transport_tls.h>
@@ -49,18 +48,12 @@ class SIPAccount : public SIPAccountBase
 public:
     constexpr static auto ACCOUNT_TYPE = ACCOUNT_TYPE_SIP;
 
-    std::shared_ptr<SIPAccount> shared()
-    {
-        return std::static_pointer_cast<SIPAccount>(shared_from_this());
-    }
+    std::shared_ptr<SIPAccount> shared() { return std::static_pointer_cast<SIPAccount>(shared_from_this()); }
     std::shared_ptr<SIPAccount const> shared() const
     {
         return std::static_pointer_cast<SIPAccount const>(shared_from_this());
     }
-    std::weak_ptr<SIPAccount> weak()
-    {
-        return std::static_pointer_cast<SIPAccount>(shared_from_this());
-    }
+    std::weak_ptr<SIPAccount> weak() { return std::static_pointer_cast<SIPAccount>(shared_from_this()); }
     std::weak_ptr<SIPAccount const> weak() const
     {
         return std::static_pointer_cast<SIPAccount const>(shared_from_this());
@@ -74,10 +67,7 @@ public:
 
     ~SIPAccount() noexcept;
 
-    const SipAccountConfig& config() const
-    {
-        return *static_cast<const SipAccountConfig*>(&Account::config());
-    }
+    const SipAccountConfig& config() const { return *static_cast<const SipAccountConfig*>(&Account::config()); }
 
     std::unique_ptr<AccountConfig> buildConfig() const override
     {
@@ -85,8 +75,7 @@ public:
     }
     inline void editConfig(std::function<void(SipAccountConfig& conf)>&& edit)
     {
-        Account::editConfig(
-            [&](AccountConfig& conf) { edit(*static_cast<SipAccountConfig*>(&conf)); });
+        Account::editConfig([&](AccountConfig& conf) { edit(*static_cast<SipAccountConfig*>(&conf)); });
     }
 
     std::string_view getAccountType() const override { return ACCOUNT_TYPE; }
@@ -130,7 +119,10 @@ public:
     /**
      * updates SIP account profile
      */
-    void updateProfile(const std::string& displayName, const std::string& avatar, const std::string& fileType, int32_t flag) override;
+    void updateProfile(const std::string& displayName,
+                       const std::string& avatar,
+                       const std::string& fileType,
+                       int32_t flag) override;
 
     /**
      * Initialize the SIP voip link with the account parameters and send registration
@@ -165,10 +157,7 @@ public:
 
     bool hasCredentials() const { return not config().credentials.empty(); }
 
-    std::vector<std::map<std::string, std::string>> getCredentials() const
-    {
-        return config().getCredentials();
-    }
+    std::vector<std::map<std::string, std::string>> getCredentials() const { return config().getCredentials(); }
 
     virtual void setRegistrationState(RegistrationState state,
                                       int code = 0,
@@ -313,8 +302,6 @@ public:
 
     virtual bool isTlsEnabled() const override { return config().tlsEnable; }
 
-    virtual bool getSrtpFallback() const override { return config().srtpFallback; }
-
     void setReceivedParameter(const std::string& received)
     {
         receivedParameter_ = received;
@@ -388,10 +375,9 @@ public:
      * @param sipTr: SIP Transport
      * @return A shared pointer on the created call.
      */
-    std::shared_ptr<SIPCall> newIncomingCall(
-        const std::string& from,
-        const std::vector<libjami::MediaMap>& mediaList,
-        const std::shared_ptr<SipTransport>& sipTr = {}) override;
+    std::shared_ptr<SIPCall> newIncomingCall(const std::string& from,
+                                             const std::vector<libjami::MediaMap>& mediaList,
+                                             const std::shared_ptr<SipTransport>& sipTr = {}) override;
 
     void onRegister(pjsip_regc_cbparam* param);
 
@@ -413,10 +399,7 @@ public:
     dhtnet::IpAddr createBindingAddress();
 
     void setActiveCodecs(const std::vector<unsigned>& list) override;
-    bool isSrtpEnabled() const override
-    {
-        return config().srtpKeyExchange != KeyExchangeProtocol::NONE;
-    }
+    bool isSrtpEnabled() const override { return config().srtpKeyExchange != KeyExchangeProtocol::NONE; }
 
     bool setPushNotificationToken(const std::string& pushDeviceToken = "") override;
     bool setPushNotificationConfig(const std::map<std::string, std::string>& data) override;
@@ -424,8 +407,7 @@ public:
     /**
      * To be called by clients with relevant data when a push notification is received.
      */
-    void pushNotificationReceived(const std::string& from,
-                                  const std::map<std::string, std::string>& data);
+    void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
 private:
     void doRegister1_();
@@ -462,8 +444,7 @@ private:
      * Callback called by the transport layer when the registration
      * transport state changes.
      */
-    virtual void onTransportStateChanged(pjsip_transport_state state,
-                                         const pjsip_transport_state_info* info);
+    virtual void onTransportStateChanged(pjsip_transport_state state, const pjsip_transport_state_info* info);
 
     struct
     {
